<?php

/**
 * GepComunicacaoLogic.
 *
 * @package Logic
 * @author  erikasouza
 *
 */
class GepComunicacaoLogic{


    private $_GepParccomunicadoLogic;
    private $_OperadorLogic;
    private $_ParcnegocioLogic;
    private $_GepPautareuniaoLogic;
    private $_GepConvocadoreuniaoLogic;
    private $_GepSolicitacaoLogic;

    const ERRO = 10;


    /**
     * Construtor da classe.
     */
    public function __construct(){
        $this->_GepParccomunicadoLogic   = new GepParccomunicadoLogic();
        $this->_OperadorLogic            = new OperadorLogic();
        $this->_ParcnegocioLogic         = new ParcnegocioLogic();
        $this->_GepPautareuniaoLogic     = new GepPautareuniaoLogic();
        $this->_GepConvocadoreuniaoLogic = new GepConvocadoreuniaoLogic();
        $this->_GepSolicitacaoLogic      = new GepSolicitacaoLogic();
    }


    /**    ok
     * Retorna o novo codigo da comunicacao.
     *
     * @param integer $nrorg Numero da Organizacao.
     *
     * @return Ambigous <number, number>
     */
    public static function novoCodigoGepComunicacao($nrorg){
        $codigo = GepComunicacaoEntity::novoCodigoGepComunicacao($nrorg);
        return $codigo;
    }


    /**
     * Envia o comunicado por email para o parceiro selecionado.
     *
     * @param string $nome_remetente     Nome do comunicador.
     * @param string $email_remetente    Email do comunicador.
     * @param string $assunto            Assunto da mensagem.
     * @param string $corpo_msg          Mensagem da comunica??o.
     * @param string $nome_destinatario  Parceiro comunicado.
     * @param string $email_destinatario Email do parceiro comunicado.
     *
     * @return boolean
     */
    public function enviaComunicadoEmail(
        $nome_remetente, $email_remetente, $assunto, $corpo_msg, $nome_destinatario, $email_destinatario
    ){
        try {
            if (empty($email_remetente) === true) {
                $email_remetente = 'gep_setforms@produto.com';
            }

            $tr = new Zend_Mail_Transport_Smtp(
                'smtp.teknisa.com',
                array(
                 'auth'     => 'login',
                 'username' => 'produto.gep@teknisa.com',
                 'password' => 'teknisa1',
                )
            );

            Zend_Mail::setDefaultTransport($tr);

            $mail = new Zend_Mail();
            $mail->setFrom($email_remetente, $nome_remetente);
            // Comentario: ($mail->setBodyHtml($corpo_msg);) .
            $mail->setBodyText($corpo_msg, 'UTF-8');
            $mail->addTo($email_destinatario, $nome_destinatario);
            $mail->setSubject($assunto);
            $mail->send();
            return true;
        }catch (Exception $e) {
            tk_warning($e->getMessage());
            return false;
        }
    }


    /**
     * Envia o comunicado para o telefone do parceiro selecionado.
     *
     * @param integer $solicitacao Numero da Solicitacao.
     * @param string  $comunicador Nome do parceiro que estao comunicando.
     * @param integer $celular     Numero do celular do parceiro comunicado.
     *
     * @return boolean
     */
    public function enviaComunicadoCelular($solicitacao, $comunicador, $celular) {

        $corpo_msg = 'NOTIFICA??O DA SOLICITA??O: '.$solicitacao;

        $corpo_msg .= " Aberta por: ".$comunicador;
        $corpo_msg .= " Aberta em: ".$data;
        $corpo_msg .= " Mensagem: GENTILEZA ENTRAR EM CONTATO COM O COMUNICADOR.";

        // Pesquisar maneira para enviar mensagens para o celular.
        return true;
    }


    /**
     * Faz os tratamentos e consulta para enviar o comunicado.
     *
     * @param integer $nrorg            Numero da organizacao.
     * @param integer $comunicado       Codigo do comunicado.
     * @param string  $corpo_msg        Mensagem do email.
     * @param string  $assunto          Assunto do email.
     * @param integer $cdoper_remetente Codigo do remetente (operador).
     *
     * @return boolean
     */
    public function executaEnvioComunicado(
        $nrorg, $comunicado, $corpo_msg, $assunto, $cdoper_remetente
    ) {
        $dados_remetente = $this->_OperadorLogic->retornaOperador($cdoper_remetente);
        $nome_remetente = $dados_remetente->getNmoperador();
        $email_remetente = $dados_remetente->getDsemailoper();

        $array_erro = array();

        $parceiros_cadastrados = $this->_GepParccomunicadoLogic->retornaParceirosComu($nrorg, $comunicado);
        foreach ($parceiros_cadastrados as $dados_parceiros) {
            $cd_parceiro = $dados_parceiros->getNrparcnegocio();
            $nm_parceiro_inserido = $dados_parceiros->getNmparccomunicado();
            $email_parceiro_inserido = $dados_parceiros->getCdcomunicaparc();

            if (empty($cd_parceiro) === false) {
                $dados_parceiro = $this->_OperadorLogic->retornaOperadorPeloNrParcNeogico($cd_parceiro, $nrorg);
                $nome_parceiro = $dados_parceiro->getNmoperador();
                $email_parceiro = $dados_parceiro->getDsemailoper();

                if (empty($email_parceiro) === false) {
                    $this->enviaComunicadoEmail(
                        $nome_remetente, $email_remetente, $assunto,
                        $corpo_msg, $nome_parceiro, $email_parceiro
                    );
                }/* else {
                    $array_erro[$i] = $nome_parceiro;
                }*/
            }

            if (empty($email_parceiro_inserido) === false) {
                $this->enviaComunicadoEmail(
                    $nome_remetente, $email_remetente, $assunto,
                    $corpo_msg, $nm_parceiro_inserido, $email_parceiro_inserido
                );
            }
        }

        /*return $array_erro;*/
        return true;
    }


    /**
     * Retorna a mensagem padronizada para o comunicado da reuniao.
     *
     * @param string  $nome_comunicador Nome do comunicador.
     * @param date    $data             Data de inclusao do comunicado.
     * @param integer $reuniao          Numero da reuniao.
     * @param integer $nrorg            Numero da organizacao.
     *
     * @return string
     */
    public function retornaMensagemComunicadoReuniao($nome_comunicador, date $data, $reuniao, $nrorg){
        $corpo_msg = "Reuniao solicitada por: ".$nome_comunicador."\n";
        $corpo_msg .= "Reuniao solicitada em: ".$data."\n\n";

        $pautas = "";
        $pautas_reuniao = $this->_GepPautareuniaoLogic->consultaPautasByReuniao($reuniao, $nrorg);
        if ($pautas_reuniao !== false) {
            $corpo_msg .= "Atencao a pauta:\n";
            foreach ($pautas_reuniao as $pauta) {
                $pautas .= "- ";
                $pautas .= $pauta->getTxpauta();
                $pautas .= ";\n";
            }

            $corpo_msg .= $pautas."\n";
        }

        $convocados = "";
        $convocados_reuniao = $this->_GepConvocadoreuniaoLogic->consultaConvocadosPorReuniao($reuniao, $nrorg);
        if ($convocados_reuniao !== false) {
            $convocados .= "Lista dos convocados pre-cadastrados:\n";
            foreach ($convocados_reuniao as $convocado) {
                $cd_convocado = $convocado->getNrparcoperador();
                $nome_convocado_inserido = $convocado->getNmconvocadoreuniao();
                $email_convocado_inserido = $convocado->getDsemailconvocado();

                if (empty($cd_convocado) === false) {
                    $dados_convocado = $this->_OperadorLogic->retornaOperadorPeloNrParcNeogico(
                        $cd_convocado, $nrorg
                    );
                    $nome_convocado = $dados_convocado->getNmoperador();
                    $email_convocado = $dados_convocado->getDsemailoper();
                    $convocados .= $nome_convocado." {".$email_convocado."}\n";
                }

                if (empty($nome_convocado_inserido) === false) {
                    $convocados .= $nome_convocado_inserido." {".$email_convocado_inserido."}\n";
                }
            }

            $corpo_msg .= $convocados."\n\n";
        }

        return $corpo_msg;
    }


    /**         ok
     * Retorna a mensagem padronizada para o comunicado da solicitacao.
     *
     * @param string  $nome_comunicador  Nome do comunicador.
     * @param string  $email_comunicador Email do comunicador.
     * @param date    $data              Data de inclusao do comunicado.
     * @param integer $soli              Numero da solicitacao.
     * @param string  $referencia        Referencia da solicitacao.
     * @param integer $nrorg             Numero da organizacao.
     *
     * @return string
     */
    public function retornaMensagemComunicadoSolicitacao($nome_comunicador, $email_comunicador, $data, $soli, $referencia, $nrorg){
        $corpo_msg = "Comunicado aberto por: ".$nome_comunicador." - $email_comunicador\n";
        $corpo_msg .= "Comunicado aberto em: ".$data."\n\n";
        $corpo_msg .= "Dados da solicitacao:\n";
        $corpo_msg .= "Codigo: ".$soli."\n";
        $corpo_msg .= "Referencia: ".$referencia."\n\n";
        $corpo_msg .= "Mensagem: \n";

        tk_warning($corpo_msg);
        return $corpo_msg;
    }


}