/* Sistemas Integrados TECNISA
   Financeiro

Nome: 1030_PAGSTP_INCLUI_ERRCNABP.SQL

Descrio:
Stored procedure auxiliar para preenchimento da tabela ERRCNABP.

BANCOS:
  - 341 ITAU
  - 237 BRADESCO
  - 151 NOSSA CAIXA
  - 399 HSBC
  - 275 ou 356 REAL
  - 422 SAFRA
  - 409 UNIBANCO
  - 033 BANESPA / SANTANDER
  - 001 BRASIL
  - 479 BOSTON
  - 104 CAIXA ECONOMICA
  - 453 RURAL
  - 749 MERCANTIL
  - 041 BANRISUL
  - 756 SICOOB
  - 748 SICREDI
P_CDBANCCNAB - Cdigo oficial do banco
P_CDERRCNABP - Cdigo do erro
P_DSERRCNABP - Descrio do erro

Para aplicar, executar e debugar
--  @C:\WIN_PRJ\SQL\END_CONV\ORACLE\1030_PAGSTP_INCLUI_ERRCNABP.SQL
-- EXECUTE INCLUI_ERRCNABP('341', '00', 'PAGAMENTO EFETUADO')
-- SET SERVEROUTPUT ON
-- DBMS_OUTPUT.PUT_LINE('xx');

Criao:
09/03/00 - Ederson

*/

CREATE OR REPLACE
PROCEDURE INCLUI_ERRCNABP
  (P_CDBANCCNAB IN VARCHAR2,
   P_CDERRCNABP IN VARCHAR2,
   P_DSERRCNABP IN VARCHAR2) IS

   V_ACHOU   NUMBER(1);
   V_CDBANCO BANCO.CDBANCO%TYPE;

BEGIN
   FOR C_BANCO IN (SELECT CDBANCO
                     FROM BANCO
                    WHERE CDBANCCNAB = P_CDBANCCNAB
                      AND CDBANCO IS NOT NULL) LOOP

      /*DELETA O BANCO DA TABELA ANTES DE INSERIR PARA NO D ERRO DE PK*/
      SELECT MAX(CDBANCO)
        INTO V_CDBANCO
        FROM ERRCNABP
       WHERE CDBANCO    = C_BANCO.CDBANCO
         AND CDERRCNABP = P_CDERRCNABP;

      IF V_CDBANCO IS NOT NULL THEN 
         DELETE FROM ERRCNABP
          WHERE CDBANCO    = C_BANCO.CDBANCO
            AND CDERRCNABP = P_CDERRCNABP;
      END IF;

      INSERT INTO ERRCNABP (CDBANCO, CDERRCNABP, DSERRCNABP) VALUES (C_BANCO.CDBANCO, P_CDERRCNABP, P_DSERRCNABP);

   END LOOP;
END;
/

BEGIN
-- BANCO ITAU 341

   INCLUI_ERRCNABP('341', '00', 'PAGAMENTO EFETUADO');
   INCLUI_ERRCNABP('341', 'AD', 'SEGMENTO X FORMA NO COMPATVEL');
   INCLUI_ERRCNABP('341', 'AE', 'DATA DE PAGAMENTO ALTERADA');
   INCLUI_ERRCNABP('341', 'AH', 'NMERO SEQUENCIAL DO REGISTRO NO LOTE INVLIDO');
   INCLUI_ERRCNABP('341', 'AJ', 'TIPO DE MOVIMENTO INVLIDO');
   INCLUI_ERRCNABP('341', 'AL', 'CDIGO DO BANCO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP('341', 'AM', 'AGNCIA DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP('341', 'AN', 'CONTA CORRENTE DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP('341', 'AO', 'NOME DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP('341', 'AP', 'DATA DE LANAMENTO/PAGAMENTO INVLIDA');
   INCLUI_ERRCNABP('341', 'BC', 'NOSSO NMERO INVLIDO');
   INCLUI_ERRCNABP('341', 'BD', 'CONFIRMAO DE PAGAMENTO AGENDADO');
   INCLUI_ERRCNABP('341', 'BE', 'PAGAMENTO AGENDADO COM FORMA ALTERADA PARA OP');
   INCLUI_ERRCNABP('341', 'CE', 'PAGAMENTO CANCELADO');
   INCLUI_ERRCNABP('341', 'IB', 'VALOR DO TTULO INVLIDO');
   INCLUI_ERRCNABP('341', 'IC', 'VALOR DO ABATIMENTO INVLIDO');
   INCLUI_ERRCNABP('341', 'ID', 'VALOR DO DESCONTO INVLIDO');
   INCLUI_ERRCNABP('341', 'IE', 'VALOR DA MORA INVLIDO');
   INCLUI_ERRCNABP('341', 'IF', 'VALOR DA MULTA INVLIDO');
   INCLUI_ERRCNABP('341', 'IG', 'VALOR DA DEDUO INVLIDO');
   INCLUI_ERRCNABP('341', 'IH', 'VALOR DO ACRSCIMO INVLIDO');
   INCLUI_ERRCNABP('341', 'II', 'DATA DE VENCIMENTO INVLIDA');
   INCLUI_ERRCNABP('341', 'IJ', 'SEQNCIA INVLIDA DE SEGMENTO');
   INCLUI_ERRCNABP('341', 'IM', 'TIPO X FORMA NO COMPATVEL');
   INCLUI_ERRCNABP('341', 'IN', 'BANCO / AGNCIA NO PERTENCEM S PRAAS DE COMPENSAO DO ITA');
   INCLUI_ERRCNABP('341', 'IP', 'DV DO CDIGO DE BARRAS INVLIDO');
   INCLUI_ERRCNABP('341', 'IQ', 'VALOR TOTAL DOS PAGAMENTOS ACIMA DO LIMITE');
   INCLUI_ERRCNABP('341', 'IR', 'PAGAMENTO ALTERADO');
   INCLUI_ERRCNABP('341', 'IS', 'PAGAMENTO NO CANCELADO OU NO ALTERADO');
   INCLUI_ERRCNABP('341', 'IT', 'PAGAMENTO INEXISTENTE');
   INCLUI_ERRCNABP('341', 'LA', 'DATA DE PAGAMENTO DE UM LOTE ALTERADA');
   INCLUI_ERRCNABP('341', 'LC', 'LOTE DE PAGAMENTOS CANCELADO');
   INCLUI_ERRCNABP('341', 'NA', 'PAGAMENTO NO AUTORIZADO');
   INCLUI_ERRCNABP('341', 'NE', 'PAGAMENTO CANCELADO');
   INCLUI_ERRCNABP('341', 'NR', 'OPERAO NO REALIZADA');
   INCLUI_ERRCNABP('341', 'RJ', 'REGISTRO REJEITADO');
   INCLUI_ERRCNABP('341', 'SS', 'SALDO INSUFICIENTE');
   INCLUI_ERRCNABP('341', 'TA', 'LOTE NO ACEITO - TOTAIS DO LOTE COM DIFERENA');
   COMMIT;
END;
/
BEGIN
-- BANCO BRADESCO 237

   INCLUI_ERRCNABP ('237', '00', 'CRDITO OU DBITO EFETIVADO');
	INCLUI_ERRCNABP ('237', '01', 'INSUFICINCIA DE FUNDOS - DBITO NO EFETUADO');
	INCLUI_ERRCNABP ('237', '02', 'CRDITO OU DBITO CANCELADO PELO PAGADOR/CREDOR');
	INCLUI_ERRCNABP ('237', '03', 'DBITO AUTORIZADO PELA AGNCIA - EFETUADO');
	INCLUI_ERRCNABP ('237', 'AA', 'CONTROLE INVLIDO');
	INCLUI_ERRCNABP ('237', 'AB', 'TIPO DE OPERAO INVLIDO');
	INCLUI_ERRCNABP ('237', 'AC', 'TIPO DE SERVIO INVLIDO');
	INCLUI_ERRCNABP ('237', 'AD', 'FORMA DE LANAMENTO INVLIDA');
	INCLUI_ERRCNABP ('237', 'AE', 'TIPO/NMERO DE INSCRIO INVLIDO');
	INCLUI_ERRCNABP ('237', 'AF', 'CDIGO DE CONVNIO INVLIDO');
	INCLUI_ERRCNABP ('237', 'AG', 'AGNCIA/CONTA CORRENTE/DV INVLIDO');
	INCLUI_ERRCNABP ('237', 'AH', 'N SEQUENCIAL DO REGISTRO NO LOTE INVLIDO');
	INCLUI_ERRCNABP ('237', 'AI', 'CDIGO DE SEGMENTO DE DETALHE INVLIDO');
	INCLUI_ERRCNABP ('237', 'AJ', 'TIPO DE MOVIMENTO INVLIDO');
	INCLUI_ERRCNABP ('237', 'AK', 'CDIGO DA CMARA DE COMPENSAO DO BANCO FAVORECIDO/DEPOSITRIO INVLIDO');
	INCLUI_ERRCNABP ('237', 'AL', 'CDIGO DO BANCO FAVORECIDO OU DEPOSITRIO INVLIDO');
	INCLUI_ERRCNABP ('237', 'AM', 'AGNCIA MANTENEDORA DA CONTA CORRENTE DO FAVORECIDO INVLIDA');
	INCLUI_ERRCNABP ('237', 'AN', 'CONTA CORRENTE/DV DO FAVORECIDO INVLIDO');
	INCLUI_ERRCNABP ('237', 'AO', 'NOME DO FAVORECIDO NO INFORMADO');
	INCLUI_ERRCNABP ('237', 'AP', 'DATA LANAMENTO INVLIDO');
	INCLUI_ERRCNABP ('237', 'AQ', 'TIPO/QUANTIDADE DA MOEDA INVLIDO');
	INCLUI_ERRCNABP ('237', 'AR', 'VALOR DO LANAMENTO INVLIDO');
	INCLUI_ERRCNABP ('237', 'AS', 'AVISO AO FAVORECIDO - IDENTIFICAO INVLIDA');
	INCLUI_ERRCNABP ('237', 'AT', 'TIPO/NMERO DE INSCRIO DO FAVORECIDO INVLIDO');
	INCLUI_ERRCNABP ('237', 'AU', 'LOGRADOURO DO FAVORECIDO NO INFORMADO');
	INCLUI_ERRCNABP ('237', 'AV', 'N DO LOCAL DO FAVORECIDO NO INFORMADO');
	INCLUI_ERRCNABP ('237', 'AW', 'CIDADE DO FAVORECIDO NO INFORMADA');
	INCLUI_ERRCNABP ('237', 'AX', 'CEP/COMPLEMENTO DO FAVORECIDO INVLIDO');
	INCLUI_ERRCNABP ('237', 'AY', 'SIGLA DO ESTADO DO FAVORECIDO INVLIDA');
	INCLUI_ERRCNABP ('237', 'AZ', 'CDIGO/NOME DO BANCO DEPOSITRIO INVLIDO');
	INCLUI_ERRCNABP ('237', 'BA', 'CDIGO/NOME DA AGNCIA DEPOSITRIA NO INFORMADO');
	INCLUI_ERRCNABP ('237', 'BB', 'SEU NMERO INVLIDO');
	INCLUI_ERRCNABP ('237', 'BC', 'NOSSO NMERO INVLIDO');
	INCLUI_ERRCNABP ('237', 'BD', 'INCLUSO EFETUADA COM SUCESSO');
	INCLUI_ERRCNABP ('237', 'BE', 'ALTERAO EFETUADA COM SUCESSO');
	INCLUI_ERRCNABP ('237', 'BF', 'EXCLUSO EFETUADA COM SUCESSO');
	INCLUI_ERRCNABP ('237', 'BG', 'AGNCIA/CONTA IMPEDIDA LEGALMENTE');
	INCLUI_ERRCNABP ('237', 'BH', 'EMPRESA NO PAGOU SALRIO');
	INCLUI_ERRCNABP ('237', 'BI', 'FALECIMENTO DO MUTURIO');
	INCLUI_ERRCNABP ('237', 'BJ', 'EMPRESA NO ENVIOU REMESSA DO MUTURIO');
	INCLUI_ERRCNABP ('237', 'BK', 'EMPRESA NO ENVIOU REMESSA NO VENCIMENTO');
	INCLUI_ERRCNABP ('237', 'BL', 'VALOR DA PARCELA INVLIDA');
	INCLUI_ERRCNABP ('237', 'BM', 'IDENTIFICAO DO CONTRATO INVLIDA');
	INCLUI_ERRCNABP ('237', 'BN', 'OPERAO DE CONSIGNAO INCLUDA COM SUCESSO');
	INCLUI_ERRCNABP ('237', 'BO', 'OPERAO DE CONSIGNAO ALTERADA COM SUCESSO');
	INCLUI_ERRCNABP ('237', 'BP', 'OPERAO DE CONSIGNAO EXCLUDA COM SUCESSO');
	INCLUI_ERRCNABP ('237', 'BQ', 'OPERAO DE CONSIGNAO LIQUIDADA COM SUCESSO');
	INCLUI_ERRCNABP ('237', 'CA', 'CDIGO DE BARRAS - CDIGO DO BANCO INVLIDO');
	INCLUI_ERRCNABP ('237', 'CB', 'CDIGO DE BARRAS - CDIGO DA MOEDA INVLIDO');
	INCLUI_ERRCNABP ('237', 'CC', 'CDIGO DE BARRAS - DGITO VERIFICADOR GERAL INVLIDO');
	INCLUI_ERRCNABP ('237', 'CD', 'CDIGO DE BARRAS - VALOR DO TTULO INVLIDO');
	INCLUI_ERRCNABP ('237', 'CE', 'CDIGO DE BARRAS - CAMPO LIVRE INVLIDO');
	INCLUI_ERRCNABP ('237', 'CF', 'VALOR DO DOCUMENTO INVLIDO');
	INCLUI_ERRCNABP ('237', 'CG', 'VALOR DO ABATIMENTO INVLIDO');
	INCLUI_ERRCNABP ('237', 'CH', 'VALOR DO DESCONTO INVLIDO');
	INCLUI_ERRCNABP ('237', 'CI', 'VALOR DE MORA INVLIDO');
	INCLUI_ERRCNABP ('237', 'CJ', 'VALOR DA MULTA INVLIDO');
	INCLUI_ERRCNABP ('237', 'CK', 'VALOR DO IR INVLIDO');
	INCLUI_ERRCNABP ('237', 'CL', 'VALOR DO ISS INVLIDO');
	INCLUI_ERRCNABP ('237', 'CM', 'VALOR DO IOF INVLIDO');
	INCLUI_ERRCNABP ('237', 'CN', 'VALOR DE OUTRAS DEDUES INVLIDO');
	INCLUI_ERRCNABP ('237', 'CO', 'VALOR DE OUTROS ACRSCIMOS INVLIDO');
	INCLUI_ERRCNABP ('237', 'CP', 'VALOR DO INSS INVLIDO');
	INCLUI_ERRCNABP ('237', 'HA', 'LOTE NO ACEITO');
	INCLUI_ERRCNABP ('237', 'HB', 'INSCRIO DA EMPRESA INVLIDA PARA O CONTRATO');
	INCLUI_ERRCNABP ('237', 'HC', 'CONVNIO COM A EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
	INCLUI_ERRCNABP ('237', 'HD', 'AGNCIA/CONTA CORRENTE DA EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
	INCLUI_ERRCNABP ('237', 'HE', 'TIPO DE SERVIO INVLIDO PARA O CONTRATO');
	INCLUI_ERRCNABP ('237', 'HF', 'CONTA CORRENTE DA EMPRESA COM SALDO INSUFICIENTE');
	INCLUI_ERRCNABP ('237', 'HG', 'LOTE DE SERVIO FORA DE SEQUNCIA');
	INCLUI_ERRCNABP ('237', 'HH', 'LOTE DE SERVIO INVLIDO');
	INCLUI_ERRCNABP ('237', 'HI', 'ARQUIVO NO ACEITO');
	INCLUI_ERRCNABP ('237', 'HJ', 'TIPO DE REGISTRO INVLIDO');
	INCLUI_ERRCNABP ('237', 'HK', 'CDIGO REMESSA / RETORNO INVLIDO');
	INCLUI_ERRCNABP ('237', 'HL', 'VERSO DE LAYOUT INVLIDA');
	INCLUI_ERRCNABP ('237', 'HM', 'MUTURIO NO IDENTIFICADO');
	INCLUI_ERRCNABP ('237', 'HN', 'TIPO DO BENEFCIO NO PERMITE EMPRSTIMO');
	INCLUI_ERRCNABP ('237', 'HO', 'BENEFICIO CESSADO/SUSPENSO');
	INCLUI_ERRCNABP ('237', 'HP', 'BENEFICIO POSSUI REPRESENTANTE LEGAL');
	INCLUI_ERRCNABP ('237', 'HQ', 'BENEFCIO  DO TIPO PA (PENSO ALIMENTCIA)');
	INCLUI_ERRCNABP ('237', 'HR', 'QUANTIDADE DE CONTRATOS PERMITIDA EXCEDIDA');
	INCLUI_ERRCNABP ('237', 'HS', 'BENEFCIO NO PERTENCE AO BANCO INFORMADO');
	INCLUI_ERRCNABP ('237', 'HT', 'INCIO DO DESCONTO INFORMADO J ULTRAPASSADO');
	INCLUI_ERRCNABP ('237', 'HU', 'NMERO DA PARCELA INVLIDA');
	INCLUI_ERRCNABP ('237', 'HV', 'QUANTIDADE DE PARCELA INVLIDA');
	INCLUI_ERRCNABP ('237', 'HW', 'MARGEM CONSIGNVEL EXCEDIDA PARA O MUTURIO DENTRO DO PRAZO DO CONTRATO');
	INCLUI_ERRCNABP ('237', 'HX', 'EMPRSTIMO J CADASTRADO');
	INCLUI_ERRCNABP ('237', 'HY', 'EMPRSTIMO INEXISTENTE');
	INCLUI_ERRCNABP ('237', 'HZ', 'EMPRSTIMO J ENCERRADO');
	INCLUI_ERRCNABP ('237', 'H1', 'ARQUIVO SEM TRAILER');
	INCLUI_ERRCNABP ('237', 'H2', 'MUTURIO SEM CRDITO NA COMPETNCIA');
	INCLUI_ERRCNABP ('237', 'H3', 'NO DESCONTADO  OUTROS MOTIVOS');
	INCLUI_ERRCNABP ('237', 'H4', 'RETORNO DE CRDITO NO PAGO');
	INCLUI_ERRCNABP ('237', 'H5', 'CANCELAMENTO DE EMPRSTIMO RETROATIVO');
	INCLUI_ERRCNABP ('237', 'H6', 'OUTROS MOTIVOS DE GLOSA');
	INCLUI_ERRCNABP ('237', 'H7', 'MARGEM CONSIGNVEL EXCEDIDA PARA O MUTURIO ACIMA DO PRAZO DO CONTRATO');
	INCLUI_ERRCNABP ('237', 'H8', 'MUTURIO DESLIGADO DO EMPREGADOR');
	INCLUI_ERRCNABP ('237', 'H9', 'MUTURIO AFASTADO POR LICENA');
	INCLUI_ERRCNABP ('237', 'IA', 'PRIMEIRO NOME DO MUTURIO DIFERENTE DO PRIMEIRO NOME DO MOVIMENTO DO CENSO OU DIFERENTE DA BASE DE TITULAR DO BENEFCIO');
	INCLUI_ERRCNABP ('237', 'TA', 'LOTE NO ACEITO - TOTAIS DO LOTE COM DIFERENA');
	INCLUI_ERRCNABP ('237', 'YA', 'TTULO NO ENCONTRADO');
	INCLUI_ERRCNABP ('237', 'YB', 'IDENTIFICADOR REGISTRO OPCIONAL INVLIDO');
	INCLUI_ERRCNABP ('237', 'YC', 'CDIGO PADRO INVLIDO');
	INCLUI_ERRCNABP ('237', 'YD', 'CDIGO DE OCORRNCIA INVLIDO');
	INCLUI_ERRCNABP ('237', 'YE', 'COMPLEMENTO DE OCORRNCIA INVLIDO');
	INCLUI_ERRCNABP ('237', 'YF', 'ALEGAO J INFORMADA');
	INCLUI_ERRCNABP ('237', 'ZA', 'AGNCIA / CONTA DO FAVORECIDO SUBSTITUDA');
	INCLUI_ERRCNABP ('237', 'ZB', 'DIVERGNCIA ENTRE O PRIMEIRO E LTIMO NOME DO BENEFICIRIO VERSUS PRIMEIRO E LTIMO NOME NA RECEITA FEDERAL');
	INCLUI_ERRCNABP ('237', 'ZC', 'CONFIRMAO DE ANTECIPAO DE VALOR');
	INCLUI_ERRCNABP ('237', 'ZD', 'ANTECIPAO PARCIAL DE VALOR');
	INCLUI_ERRCNABP ('237', '5A', 'AGENDADO SOB LISTA DE DEBITO');
	INCLUI_ERRCNABP ('237', '5B', 'PAGAMENTO NO AUTORIZA SOB LISTA DE DEBITO');
	INCLUI_ERRCNABP ('237', '5C', 'LISTA COM MAIS DE UMA MODALIDADE');
	INCLUI_ERRCNABP ('237', '5D', 'LISTA COM MAIS DE UMA DATA DE PAGAMENTO');
	INCLUI_ERRCNABP ('237', '5E', 'NMERO DE LISTA DUPLICADO');
	INCLUI_ERRCNABP ('237', '5F', ' LISTA DE DEBITO VENCIDA E NO AUTORIZADA');
	INCLUI_ERRCNABP ('237', '5M', 'NMERO DE LISTA DE DEBITO INVALIDA');
   COMMIT;
END;
/
BEGIN
-- BANCO NOSSA CAIXA 151

   INCLUI_ERRCNABP('151', '00', 'CRDITO OU DBITO EFETUADO');
   INCLUI_ERRCNABP('151', '01', 'INSUFICINCIA DE FUNDOS - DBITO NO EFETUADO');
   INCLUI_ERRCNABP('151', '02', 'CRDITO OU DBITO CANCELADO PELO PAGADOR/CREDOR');
   INCLUI_ERRCNABP('151', '03', 'DBITO AUTORIZADO PELA AGNCIA - EFETUADO');
   INCLUI_ERRCNABP('151', 'HA', 'LOTE NO ACEITO');
   INCLUI_ERRCNABP('151', 'HB', 'INSCRIO DA EMPRESA INVLIDA PARA O CONTRATO');
   INCLUI_ERRCNABP('151', 'HC', 'CONVNIO COM A EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP('151', 'HD', 'AGNCIA / CONTA CORRENTE DA EMPRESA INEXISTENTE/INVLIDA PARA O CONTRATO');
   INCLUI_ERRCNABP('151', 'HE', 'TIPO DE SERVIO INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP('151', 'HF', 'CONTA CORRENTE DA EMPRESA COM SALDO INSUFICIENTE');
   INCLUI_ERRCNABP('151', 'AA', 'CONTROLE INVLIDO');
   INCLUI_ERRCNABP('151', 'AB', 'TIPO DE OPERAO INVLIDO');
   INCLUI_ERRCNABP('151', 'AC', 'TIPO DE SERVIO INVLIDO');
   INCLUI_ERRCNABP('151', 'AD', 'FORMA DE LANAMENTO INVLIDA');
   INCLUI_ERRCNABP('151', 'AE', 'TIPO/NMERO DE INSCRIO INVLIDO');
   INCLUI_ERRCNABP('151', 'AF', 'CDIGO DE CONVNIO INVLIDO');
   INCLUI_ERRCNABP('151', 'AG', 'AGNCIA / CONTA CORRENTE/DV INVLIDO');
   INCLUI_ERRCNABP('151', 'AH', 'NMERO SEQUENCIAL DO REGISTRO NO LOTE INVLIDO');
   INCLUI_ERRCNABP('151', 'AI', 'CDIGO DE SEGMENTO DE DETALHE INVLIDO');
   INCLUI_ERRCNABP('151', 'AJ', 'TIPO DE MOVIMENTO INVLIDO');
   INCLUI_ERRCNABP('151', 'AK', 'CDIGO DA CMARA DE COMPENSAO DO BANCO DO FAVORECIDO/DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP('151', 'AL', 'CDIGO DO BANCO DO FAVORECIDO OU DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP('151', 'AM', 'AGNCIA MANTENEDORA DA CONTA CORRENTE DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP('151', 'AN', 'CONTA CORRENTE/DV DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP('151', 'AO', 'NOME DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP('151', 'AP', 'DATA LANAMENTO INVLIDA');
   INCLUI_ERRCNABP('151', 'AQ', 'TIPO/QUANTIDADE DA MOEDA INVLIDO');
   INCLUI_ERRCNABP('151', 'AR', 'VALOR DO LANAMENTO INVLIDO');
   INCLUI_ERRCNABP('151', 'AS', 'AVISO AO FAVORECIDO - IDENTIFICAO INVLIDA');
   INCLUI_ERRCNABP('151', 'AT', 'TIPO/NMERO DE INSCRIO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP('151', 'AU', 'LOGRADOURO DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP('151', 'AV', 'NMERO DO LOCAL DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP('151', 'AW', 'CIDADE DO FAVORECIDO NO INFORMADA');
   INCLUI_ERRCNABP('151', 'AX', 'CEP/COMPLEMENTO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP('151', 'AY', 'SIGLA DO ESTADO DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP('151', 'AZ', 'CDIGO/NOME DO BANCO DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP('151', 'BA', 'CDIGO/NOME DA AGNCIA DEPOSITRIA NO INFORMADO');
   INCLUI_ERRCNABP('151', 'BD', 'CONFIRMAO DE PAGAMENTO AGENDADO');
   COMMIT;
END;
/
BEGIN
-- BANCO HSBC 399

   INCLUI_ERRCNABP('399', '00', 'CRDITO EFETUADO');
   INCLUI_ERRCNABP('399', '01', 'INSUFICINCIA DE FUNDOS - DBITO NO EFETUADO');
   INCLUI_ERRCNABP('399', '02', 'CANCELAMENTO ACEITO');
   INCLUI_ERRCNABP('399', '34', 'CONTA CORRENTE DE DBITO BLOQUEADA');
   INCLUI_ERRCNABP('399', '40', 'CONTA CORRENTE/POUPANA PARA CRDITO BLOQUEADA');
   INCLUI_ERRCNABP('399', '42', 'CDIGO DE BARRAS INVLIDO');
   INCLUI_ERRCNABP('399', '51', 'DATA DESCONTO INVLIDA');
   INCLUI_ERRCNABP('399', '52', 'DATA DESCONTO MAIOR QUE DATA VENCIMENTO');
   INCLUI_ERRCNABP('399', '54', 'VALOR DO DESCONTO INVLIDO');
   INCLUI_ERRCNABP('399', '56', 'COMPROMISSO DE AGENDAMENTO AUTOMTICO INCORRETO');
   INCLUI_ERRCNABP('399', '57', 'COMPROMISSO DE AGENDAMENTO AUTOMTICO J PROCESSADO');
   INCLUI_ERRCNABP('399', '58', 'COMPROMISSO DE AGENDAMENTO AUTOMTICO NO ENCONTRADO');
   INCLUI_ERRCNABP('399', '59', 'COMPROMISSO DE AGENDAMENTO AUTOMTICO COM VALOR INVLIDO');
   INCLUI_ERRCNABP('399', '60', 'COMPROMISSO DE AGENDAMENTO AUTOMTICO DATA VENCIMENTO INVLIDA');
   INCLUI_ERRCNABP('399', '61', 'NMERO DO DOCUMENTO DA PARCELA COBRANA NO REGISTRADA HSBC INVLIDO (CDIGO DO CEDENTE)');
   INCLUI_ERRCNABP('399', '62', 'VALOR DO LANAMENTO DA PARCELA COBRANA NO REGISTRADA HSBC INVLIDO');
   INCLUI_ERRCNABP('399', '63', 'CDIGO DO DOCUMENTO DA PARCELA COBRANA NO REGISTRADA HSBC INVLIDO');
   INCLUI_ERRCNABP('399', '64', 'DATA DO VENCIMENTO DA PARCELA COBRANA NO REGISTRADA HSBC INVLIDA');
   INCLUI_ERRCNABP('399', '65', 'PARCELA "COBRANA NO REGISTRADA HSBC" J CADASTRADA');
   INCLUI_ERRCNABP('399', '66', 'VALOR ACIMA DE R$ 999.999.999,99');
   INCLUI_ERRCNABP('399', '67', 'CONTA CORRENTE VINCULADA IRREGULAR');
   INCLUI_ERRCNABP('399', '68', 'BLOQUEIO/CANCELAMENTO INDEFERIDO PARA CHEQUE SALRIO');
   INCLUI_ERRCNABP('399', '69', 'CHEQUE SALRIO INCOMPATVEL COM TIPO DE PAGAMENTO');
   INCLUI_ERRCNABP('399', '72', 'TTULO INATIVO');
   INCLUI_ERRCNABP('399', '73', 'TTULO BLOQUEADO PELO CEDENTE');
   INCLUI_ERRCNABP('399', '74', 'TTULO INEXISTENTE');
   INCLUI_ERRCNABP('399', '75', 'CEDENTE INFORMADO INEXISTENTE');
   INCLUI_ERRCNABP('399', '76', 'CPF/CNPJ DO CREDOR DIVERGENTE/INVLIDO');
   INCLUI_ERRCNABP('399', '77', 'AGNCIA E/OU CONTA CORRENTE ENCERRADA');
   INCLUI_ERRCNABP('399', '78', 'AGNCIA E/OU CONTA CORRENTE INVLIDA/INEXISTENTE');
   INCLUI_ERRCNABP('399', '79', 'DADOS DO CREDOR INVLIDO');
   INCLUI_ERRCNABP('399', '80', 'MOTIVO NO ESCLARECIDO');
   INCLUI_ERRCNABP('399', '81', 'PROCESSO INDISPONVEL NO MOMENTO');
   INCLUI_ERRCNABP('399', '83', 'TIPO DE CONTA DIFERENCIADA');
   INCLUI_ERRCNABP('399', '90', 'TTULO PAGO EM DUPLICIDADE');
   INCLUI_ERRCNABP('399', '92', 'VALOR A PAGAR IGUAL A ZEROS');
   INCLUI_ERRCNABP('399', '93', 'VALOR DESCONTO MAIOR QUE TTULO');
   INCLUI_ERRCNABP('399', '94', 'VALOR DO TTULO NO CONFERE');
   INCLUI_ERRCNABP('399', '95', 'TTULO J BAIXADO');
   INCLUI_ERRCNABP('399', '96', 'TTULO J DEVOLVIDO');
   INCLUI_ERRCNABP('399', '97', 'TTULO J LIQUIDADO');
   INCLUI_ERRCNABP('399', 'AA', 'CONTROLE INVLIDO');
   INCLUI_ERRCNABP('399', 'AC', 'TIPO DE SERVIO INVLIDO');
   INCLUI_ERRCNABP('399', 'AG', 'AGNCIA/CONTA CORRENTE/DV INVLIDO');
   INCLUI_ERRCNABP('399', 'AJ', 'TIPO DE MOVIMENTO INVLIDO');
   INCLUI_ERRCNABP('399', 'AM', 'BANCO, AGNCIA DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP('399', 'AN', 'CONTA CORRENTE DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP('399', 'AO', 'NOME FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP('399', 'AP', 'DATA LANAMENTO INVLIDA');
   INCLUI_ERRCNABP('399', 'AQ', 'TIPO OU QUANTIDADE DA MOEDA INVLIDO');
   INCLUI_ERRCNABP('399', 'AR', 'VALOR DO LANAMENTO INVLIDO');
   INCLUI_ERRCNABP('399', 'AZ', 'CDIGO BANCO DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP('399', 'BB', 'SEU NMERO INVLIDO');
   INCLUI_ERRCNABP('399', 'BC', 'NOSSO NMERO INVLIDO');
   INCLUI_ERRCNABP('399', 'BD', 'CONFIRMAO PAGAMENTO AGENDADO');
   INCLUI_ERRCNABP('399', 'BO', 'BANCO NO ESTA OPERANDO C/TED');
   INCLUI_ERRCNABP('399', 'CP', 'VALOR DO INSS INVLIDO');
   INCLUI_ERRCNABP('399', 'CQ', 'CDIGO DE PAGAMENTO DE GUIA DA PREVIDNCIA SOCIAL INVLIDO');
   INCLUI_ERRCNABP('399', 'CR', 'COMPETNCIA INVLIDA');
   INCLUI_ERRCNABP('399', 'CS', 'IDENTIFICAO DO CONTRIBUINTE INVLIDA');
   INCLUI_ERRCNABP('399', 'CT', 'OUTROS ERROS');
   INCLUI_ERRCNABP('399', 'DA', 'CDIGO DA RECEITA INVLIDO/INCORRETO');
   INCLUI_ERRCNABP('399', 'DC', 'NMERO REFERNCIA INVLIDO/INCORRETO');
   INCLUI_ERRCNABP('399', 'DE', 'VALOR RECEITA BRUTA INVLIDO/INCORRETO');
   INCLUI_ERRCNABP('399', 'DG', 'PERCENTUAL INFORMADO INVLIDO/INCORRETO');
   INCLUI_ERRCNABP('399', 'HA', 'LOTE NO ACEITO');
   INCLUI_ERRCNABP('399', 'HB', 'CPF/CNPJ DO ORIGINADOR DIVERGE DO CADASTRADO');
   INCLUI_ERRCNABP('399', 'HC', 'CONVNIO COM A EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP('399', 'HE', 'TIPO DE PAGAMENTO NO PERMITIDO PARA O CONTRATO');
   INCLUI_ERRCNABP('399', 'HF', 'VALOR COMPROMISSO EXCEDE VALOR LIMITE DIRIO');
   INCLUI_ERRCNABP('399', 'OH', 'CONTRATO CANCELADO');
   INCLUI_ERRCNABP('399', 'YW', 'PROBLEMAS OPERACIONAIS');
   COMMIT;
END;
/
BEGIN
-- BANCO REAL 356

   INCLUI_ERRCNABP ('356', '00', 'CRDITO OU DBITO EFETIVADO  ESTE CDIGO INDICA QUE O PAGAMENTO FOI CONFIRMADO');
   INCLUI_ERRCNABP ('356', '01', 'INSUFICINCIA DE FUNDOS - DBITO NO EFETUADO');
   INCLUI_ERRCNABP ('356', '02', 'CRDITO OU DBITO CANCELADO PELO PAGADOR/CREDOR');
   INCLUI_ERRCNABP ('356', '03', 'DBITO AUTORIZADO PELA AGNCIA - EFETUADO');
   INCLUI_ERRCNABP ('356', 'HA', 'LOTE NO ACEITO');
   INCLUI_ERRCNABP ('356', 'HB', 'INSCRIO DA EMPRESA INVLIDA PARA O CONTRATO');
   INCLUI_ERRCNABP ('356', 'HC', 'CONVNIO COM A EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('356', 'HD', 'AGNCIA/CONTA CORRENTE DA EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('356', 'HE', 'TIPO DE SERVIO INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('356', 'HF', 'CONTA CORRENTE DA EMPRESA COM SALDO INSUFICIENTE');
   INCLUI_ERRCNABP ('356', 'HG', 'LOTE DE SERVIO FORA DE SEQNCIA');
   INCLUI_ERRCNABP ('356', 'HH', 'LOTE DE SERVIO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AA', 'CONTROLE INVLIDO');
   INCLUI_ERRCNABP ('356', 'AB', 'TIPO DE OPERAO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AC', 'TIPO DE SERVIO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AD', 'FORMA DE LANAMENTO INVLIDA');
   INCLUI_ERRCNABP ('356', 'AE', 'TIPO/NMERO DE INSCRIO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AF', 'CDIGO DE CONVNIO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AG', 'AGNCIA/CONTA CORRENTE/DV INVLIDO');
   INCLUI_ERRCNABP ('356', 'AH', 'N SEQENCIAL DO REGISTRO NO LOTE INVLIDO');
   INCLUI_ERRCNABP ('356', 'AI', 'CDIGO DE SEGMENTO DE DETALHE INVLIDO');
   INCLUI_ERRCNABP ('356', 'AJ', 'TIPO DE MOVIMENTO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AK', 'CDIGO DA CMARA DE COMPENSAO DO BANCO FAVORECIDO/DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AL', 'CDIGO DO BANCO FAVORECIDO OU DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AM', 'AGNCIA MANTENEDORA DA CONTA CORRENTE DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP ('356', 'AN', 'CONTA CORRENTE/DV DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AO', 'NOME DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('356', 'AP', 'DATA LANAMENTO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AQ', 'TIPO/QUANTIDADE DA MOEDA INVLIDO');
   INCLUI_ERRCNABP ('356', 'AR', 'VALOR DO LANAMENTO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AS', 'AVISO AO FAVORECIDO - IDENTIFICAO INVLIDA');
   INCLUI_ERRCNABP ('356', 'AT', 'TIPO/NMERO DE INSCRIO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AU', 'LOGRADOURO DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('356', 'AV', 'N DO LOCAL DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('356', 'AW', 'CIDADE DO FAVORECIDO NO INFORMADA ');
   INCLUI_ERRCNABP ('356', 'AX', 'CEP/COMPLEMENTO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AY', 'SIGLA DO ESTADO DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP ('356', 'AZ', 'CDIGO/NOME DO BANCO DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('356', 'BA', 'CDIGO/NOME DA AGNCIA DEPOSITRIA NO INFORMADO');
   INCLUI_ERRCNABP ('356', 'BB', 'SEU NMERO INVLIDO');
   INCLUI_ERRCNABP ('356', 'BC', 'NOSSO NMERO INVLIDO');
   INCLUI_ERRCNABP ('356', 'BD', 'INCLUSO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP ('356', 'BE', 'ALTERAO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP ('356', 'BF', 'EXCLUSO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP ('356', 'BG', 'AGNCIA/CONTA IMPEDIDA LEGALMENTE');
   INCLUI_ERRCNABP ('356', 'CA', 'CDIGO DE BARRAS - CDIGO DO BANCO INVLIDO');
   INCLUI_ERRCNABP ('356', 'CB', 'CDIGO DE BARRAS - CDIGO DA MOEDA INVLIDO');
   INCLUI_ERRCNABP ('356', 'CC', 'CDIGO DE BARRAS - DGITO VERIFICADOR GERAL INVLIDO');
   INCLUI_ERRCNABP ('356', 'CD', 'CDIGO DE BARRAS - VALOR DO TTULO INVLIDO');
   INCLUI_ERRCNABP ('356', 'CE', 'CDIGO DE BARRAS - CAMPO LIVRE INVLIDO');
   INCLUI_ERRCNABP ('356', 'CF', 'VALOR DO DOCUMENTO INVLIDO');
   INCLUI_ERRCNABP ('356', 'CG', 'VALOR DO ABATIMENTO INVLIDO');
   INCLUI_ERRCNABP ('356', 'CH', 'VALOR DO DESCONTO INVLIDO');
   INCLUI_ERRCNABP ('356', 'CI', 'VALOR DE MORA INVLIDO');
   INCLUI_ERRCNABP ('356', 'CJ', 'VALOR DA MULTA INVLIDO');
   INCLUI_ERRCNABP ('356', 'CK', 'VALOR DO IR INVLIDO');
   INCLUI_ERRCNABP ('356', 'CL', 'VALOR DO ISS INVLIDO');
   INCLUI_ERRCNABP ('356', 'CM', 'VALOR DO IOF INVLIDO');
   INCLUI_ERRCNABP ('356', 'CN', 'VALOR DE OUTRAS DEDUES INVLIDO');
   INCLUI_ERRCNABP ('356', 'CO', 'VALOR DE OUTROS ACRSCIMOS INVLIDO');
   INCLUI_ERRCNABP ('356', 'CP', 'VALOR DO INSS INVLIDO');
   INCLUI_ERRCNABP ('356', 'TA', 'LOTE NO ACEITO - TOTAIS DO LOTE COM DIFERENA');
   INCLUI_ERRCNABP ('356', 'YA', 'TTULO NO ENCONTRADO');
   INCLUI_ERRCNABP ('356', 'YB', 'IDENTIFICADOR REGISTRO OPCIONAL INVLIDO');
   INCLUI_ERRCNABP ('356', 'YC', 'CDIGO PADRO INVLIDO');
   INCLUI_ERRCNABP ('356', 'YD', 'CDIGO DE OCORRNCIA INVLIDO');
   INCLUI_ERRCNABP ('356', 'YE', 'COMPLEMENTO DE OCORRNCIA INVLIDO');
   INCLUI_ERRCNABP ('356', 'YF', 'ALEGAO J INFORMADA');
   COMMIT;
END;
/
BEGIN
-- BANCO REAL 275

   INCLUI_ERRCNABP ('275', '00', 'CRDITO OU DBITO EFETIVADO  ESTE CDIGO INDICA QUE O PAGAMENTO FOI CONFIRMADO');
   INCLUI_ERRCNABP ('275', '01', 'INSUFICINCIA DE FUNDOS - DBITO NO EFETUADO');
   INCLUI_ERRCNABP ('275', '02', 'CRDITO OU DBITO CANCELADO PELO PAGADOR/CREDOR');
   INCLUI_ERRCNABP ('275', '03', 'DBITO AUTORIZADO PELA AGNCIA - EFETUADO');
   INCLUI_ERRCNABP ('275', 'HA', 'LOTE NO ACEITO');
   INCLUI_ERRCNABP ('275', 'HB', 'INSCRIO DA EMPRESA INVLIDA PARA O CONTRATO');
   INCLUI_ERRCNABP ('275', 'HC', 'CONVNIO COM A EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('275', 'HD', 'AGNCIA/CONTA CORRENTE DA EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('275', 'HE', 'TIPO DE SERVIO INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('275', 'HF', 'CONTA CORRENTE DA EMPRESA COM SALDO INSUFICIENTE');
   INCLUI_ERRCNABP ('275', 'HG', 'LOTE DE SERVIO FORA DE SEQNCIA');
   INCLUI_ERRCNABP ('275', 'HH', 'LOTE DE SERVIO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AA', 'CONTROLE INVLIDO');
   INCLUI_ERRCNABP ('275', 'AB', 'TIPO DE OPERAO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AC', 'TIPO DE SERVIO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AD', 'FORMA DE LANAMENTO INVLIDA');
   INCLUI_ERRCNABP ('275', 'AE', 'TIPO/NMERO DE INSCRIO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AF', 'CDIGO DE CONVNIO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AG', 'AGNCIA/CONTA CORRENTE/DV INVLIDO');
   INCLUI_ERRCNABP ('275', 'AH', 'N SEQENCIAL DO REGISTRO NO LOTE INVLIDO');
   INCLUI_ERRCNABP ('275', 'AI', 'CDIGO DE SEGMENTO DE DETALHE INVLIDO');
   INCLUI_ERRCNABP ('275', 'AJ', 'TIPO DE MOVIMENTO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AK', 'CDIGO DA CMARA DE COMPENSAO DO BANCO FAVORECIDO/DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AL', 'CDIGO DO BANCO FAVORECIDO OU DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AM', 'AGNCIA MANTENEDORA DA CONTA CORRENTE DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP ('275', 'AN', 'CONTA CORRENTE/DV DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AO', 'NOME DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('275', 'AP', 'DATA LANAMENTO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AQ', 'TIPO/QUANTIDADE DA MOEDA INVLIDO');
   INCLUI_ERRCNABP ('275', 'AR', 'VALOR DO LANAMENTO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AS', 'AVISO AO FAVORECIDO - IDENTIFICAO INVLIDA');
   INCLUI_ERRCNABP ('275', 'AT', 'TIPO/NMERO DE INSCRIO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AU', 'LOGRADOURO DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('275', 'AV', 'N DO LOCAL DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('275', 'AW', 'CIDADE DO FAVORECIDO NO INFORMADA ');
   INCLUI_ERRCNABP ('275', 'AX', 'CEP/COMPLEMENTO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AY', 'SIGLA DO ESTADO DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP ('275', 'AZ', 'CDIGO/NOME DO BANCO DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('275', 'BA', 'CDIGO/NOME DA AGNCIA DEPOSITRIA NO INFORMADO');
   INCLUI_ERRCNABP ('275', 'BB', 'SEU NMERO INVLIDO');
   INCLUI_ERRCNABP ('275', 'BC', 'NOSSO NMERO INVLIDO');
   INCLUI_ERRCNABP ('275', 'BD', 'INCLUSO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP ('275', 'BE', 'ALTERAO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP ('275', 'BF', 'EXCLUSO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP ('275', 'BG', 'AGNCIA/CONTA IMPEDIDA LEGALMENTE');
   INCLUI_ERRCNABP ('275', 'CA', 'CDIGO DE BARRAS - CDIGO DO BANCO INVLIDO');
   INCLUI_ERRCNABP ('275', 'CB', 'CDIGO DE BARRAS - CDIGO DA MOEDA INVLIDO');
   INCLUI_ERRCNABP ('275', 'CC', 'CDIGO DE BARRAS - DGITO VERIFICADOR GERAL INVLIDO');
   INCLUI_ERRCNABP ('275', 'CD', 'CDIGO DE BARRAS - VALOR DO TTULO INVLIDO');
   INCLUI_ERRCNABP ('275', 'CE', 'CDIGO DE BARRAS - CAMPO LIVRE INVLIDO');
   INCLUI_ERRCNABP ('275', 'CF', 'VALOR DO DOCUMENTO INVLIDO');
   INCLUI_ERRCNABP ('275', 'CG', 'VALOR DO ABATIMENTO INVLIDO');
   INCLUI_ERRCNABP ('275', 'CH', 'VALOR DO DESCONTO INVLIDO');
   INCLUI_ERRCNABP ('275', 'CI', 'VALOR DE MORA INVLIDO');
   INCLUI_ERRCNABP ('275', 'CJ', 'VALOR DA MULTA INVLIDO');
   INCLUI_ERRCNABP ('275', 'CK', 'VALOR DO IR INVLIDO');
   INCLUI_ERRCNABP ('275', 'CL', 'VALOR DO ISS INVLIDO');
   INCLUI_ERRCNABP ('275', 'CM', 'VALOR DO IOF INVLIDO');
   INCLUI_ERRCNABP ('275', 'CN', 'VALOR DE OUTRAS DEDUES INVLIDO');
   INCLUI_ERRCNABP ('275', 'CO', 'VALOR DE OUTROS ACRSCIMOS INVLIDO');
   INCLUI_ERRCNABP ('275', 'CP', 'VALOR DO INSS INVLIDO');
   INCLUI_ERRCNABP ('275', 'TA', 'LOTE NO ACEITO - TOTAIS DO LOTE COM DIFERENA');
   INCLUI_ERRCNABP ('275', 'YA', 'TTULO NO ENCONTRADO');
   INCLUI_ERRCNABP ('275', 'YB', 'IDENTIFICADOR REGISTRO OPCIONAL INVLIDO');
   INCLUI_ERRCNABP ('275', 'YC', 'CDIGO PADRO INVLIDO');
   INCLUI_ERRCNABP ('275', 'YD', 'CDIGO DE OCORRNCIA INVLIDO');
   INCLUI_ERRCNABP ('275', 'YE', 'COMPLEMENTO DE OCORRNCIA INVLIDO');
   INCLUI_ERRCNABP ('275', 'YF', 'ALEGAO J INFORMADA');
   COMMIT;
END;
/
BEGIN
-- BANCO REAL 356

   INCLUI_ERRCNABP ('356', '00', 'CRDITO OU DBITO EFETIVADO  ESTE CDIGO INDICA QUE O PAGAMENTO FOI CONFIRMADO');
   INCLUI_ERRCNABP ('356', '01', 'INSUFICINCIA DE FUNDOS - DBITO NO EFETUADO');
   INCLUI_ERRCNABP ('356', '02', 'CRDITO OU DBITO CANCELADO PELO PAGADOR/CREDOR');
   INCLUI_ERRCNABP ('356', '03', 'DBITO AUTORIZADO PELA AGNCIA - EFETUADO');
   INCLUI_ERRCNABP ('356', 'HA', 'LOTE NO ACEITO');
   INCLUI_ERRCNABP ('356', 'HB', 'INSCRIO DA EMPRESA INVLIDA PARA O CONTRATO');
   INCLUI_ERRCNABP ('356', 'HC', 'CONVNIO COM A EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('356', 'HD', 'AGNCIA/CONTA CORRENTE DA EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('356', 'HE', 'TIPO DE SERVIO INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('356', 'HF', 'CONTA CORRENTE DA EMPRESA COM SALDO INSUFICIENTE');
   INCLUI_ERRCNABP ('356', 'HG', 'LOTE DE SERVIO FORA DE SEQNCIA');
   INCLUI_ERRCNABP ('356', 'HH', 'LOTE DE SERVIO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AA', 'CONTROLE INVLIDO');
   INCLUI_ERRCNABP ('356', 'AB', 'TIPO DE OPERAO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AC', 'TIPO DE SERVIO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AD', 'FORMA DE LANAMENTO INVLIDA');
   INCLUI_ERRCNABP ('356', 'AE', 'TIPO/NMERO DE INSCRIO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AF', 'CDIGO DE CONVNIO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AG', 'AGNCIA/CONTA CORRENTE/DV INVLIDO');
   INCLUI_ERRCNABP ('356', 'AH', 'N SEQENCIAL DO REGISTRO NO LOTE INVLIDO');
   INCLUI_ERRCNABP ('356', 'AI', 'CDIGO DE SEGMENTO DE DETALHE INVLIDO');
   INCLUI_ERRCNABP ('356', 'AJ', 'TIPO DE MOVIMENTO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AK', 'CDIGO DA CMARA DE COMPENSAO DO BANCO FAVORECIDO/DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AL', 'CDIGO DO BANCO FAVORECIDO OU DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AM', 'AGNCIA MANTENEDORA DA CONTA CORRENTE DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP ('356', 'AN', 'CONTA CORRENTE/DV DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AO', 'NOME DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('356', 'AP', 'DATA LANAMENTO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AQ', 'TIPO/QUANTIDADE DA MOEDA INVLIDO');
   INCLUI_ERRCNABP ('356', 'AR', 'VALOR DO LANAMENTO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AS', 'AVISO AO FAVORECIDO - IDENTIFICAO INVLIDA');
   INCLUI_ERRCNABP ('356', 'AT', 'TIPO/NMERO DE INSCRIO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AU', 'LOGRADOURO DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('356', 'AV', 'N DO LOCAL DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('356', 'AW', 'CIDADE DO FAVORECIDO NO INFORMADA ');
   INCLUI_ERRCNABP ('356', 'AX', 'CEP/COMPLEMENTO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('356', 'AY', 'SIGLA DO ESTADO DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP ('356', 'AZ', 'CDIGO/NOME DO BANCO DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('356', 'BA', 'CDIGO/NOME DA AGNCIA DEPOSITRIA NO INFORMADO');
   INCLUI_ERRCNABP ('356', 'BB', 'SEU NMERO INVLIDO');
   INCLUI_ERRCNABP ('356', 'BC', 'NOSSO NMERO INVLIDO');
   INCLUI_ERRCNABP ('356', 'BD', 'INCLUSO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP ('356', 'BE', 'ALTERAO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP ('356', 'BF', 'EXCLUSO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP ('356', 'BG', 'AGNCIA/CONTA IMPEDIDA LEGALMENTE');
   INCLUI_ERRCNABP ('356', 'CA', 'CDIGO DE BARRAS - CDIGO DO BANCO INVLIDO');
   INCLUI_ERRCNABP ('356', 'CB', 'CDIGO DE BARRAS - CDIGO DA MOEDA INVLIDO');
   INCLUI_ERRCNABP ('356', 'CC', 'CDIGO DE BARRAS - DGITO VERIFICADOR GERAL INVLIDO');
   INCLUI_ERRCNABP ('356', 'CD', 'CDIGO DE BARRAS - VALOR DO TTULO INVLIDO');
   INCLUI_ERRCNABP ('356', 'CE', 'CDIGO DE BARRAS - CAMPO LIVRE INVLIDO');
   INCLUI_ERRCNABP ('356', 'CF', 'VALOR DO DOCUMENTO INVLIDO');
   INCLUI_ERRCNABP ('356', 'CG', 'VALOR DO ABATIMENTO INVLIDO');
   INCLUI_ERRCNABP ('356', 'CH', 'VALOR DO DESCONTO INVLIDO');
   INCLUI_ERRCNABP ('356', 'CI', 'VALOR DE MORA INVLIDO');
   INCLUI_ERRCNABP ('356', 'CJ', 'VALOR DA MULTA INVLIDO');
   INCLUI_ERRCNABP ('356', 'CK', 'VALOR DO IR INVLIDO');
   INCLUI_ERRCNABP ('356', 'CL', 'VALOR DO ISS INVLIDO');
   INCLUI_ERRCNABP ('356', 'CM', 'VALOR DO IOF INVLIDO');
   INCLUI_ERRCNABP ('356', 'CN', 'VALOR DE OUTRAS DEDUES INVLIDO');
   INCLUI_ERRCNABP ('356', 'CO', 'VALOR DE OUTROS ACRSCIMOS INVLIDO');
   INCLUI_ERRCNABP ('356', 'CP', 'VALOR DO INSS INVLIDO');
   INCLUI_ERRCNABP ('356', 'TA', 'LOTE NO ACEITO - TOTAIS DO LOTE COM DIFERENA');
   INCLUI_ERRCNABP ('356', 'YA', 'TTULO NO ENCONTRADO');
   INCLUI_ERRCNABP ('356', 'YB', 'IDENTIFICADOR REGISTRO OPCIONAL INVLIDO');
   INCLUI_ERRCNABP ('356', 'YC', 'CDIGO PADRO INVLIDO');
   INCLUI_ERRCNABP ('356', 'YD', 'CDIGO DE OCORRNCIA INVLIDO');
   INCLUI_ERRCNABP ('356', 'YE', 'COMPLEMENTO DE OCORRNCIA INVLIDO');
   INCLUI_ERRCNABP ('356', 'YF', 'ALEGAO J INFORMADA');
   COMMIT;
END;
/
BEGIN
-- BANCO REAL 275

   INCLUI_ERRCNABP ('275', '00', 'CRDITO OU DBITO EFETIVADO  ESTE CDIGO INDICA QUE O PAGAMENTO FOI CONFIRMADO');
   INCLUI_ERRCNABP ('275', '01', 'INSUFICINCIA DE FUNDOS - DBITO NO EFETUADO');
   INCLUI_ERRCNABP ('275', '02', 'CRDITO OU DBITO CANCELADO PELO PAGADOR/CREDOR');
   INCLUI_ERRCNABP ('275', '03', 'DBITO AUTORIZADO PELA AGNCIA - EFETUADO');
   INCLUI_ERRCNABP ('275', 'HA', 'LOTE NO ACEITO');
   INCLUI_ERRCNABP ('275', 'HB', 'INSCRIO DA EMPRESA INVLIDA PARA O CONTRATO');
   INCLUI_ERRCNABP ('275', 'HC', 'CONVNIO COM A EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('275', 'HD', 'AGNCIA/CONTA CORRENTE DA EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('275', 'HE', 'TIPO DE SERVIO INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('275', 'HF', 'CONTA CORRENTE DA EMPRESA COM SALDO INSUFICIENTE');
   INCLUI_ERRCNABP ('275', 'HG', 'LOTE DE SERVIO FORA DE SEQNCIA');
   INCLUI_ERRCNABP ('275', 'HH', 'LOTE DE SERVIO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AA', 'CONTROLE INVLIDO');
   INCLUI_ERRCNABP ('275', 'AB', 'TIPO DE OPERAO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AC', 'TIPO DE SERVIO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AD', 'FORMA DE LANAMENTO INVLIDA');
   INCLUI_ERRCNABP ('275', 'AE', 'TIPO/NMERO DE INSCRIO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AF', 'CDIGO DE CONVNIO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AG', 'AGNCIA/CONTA CORRENTE/DV INVLIDO');
   INCLUI_ERRCNABP ('275', 'AH', 'N SEQENCIAL DO REGISTRO NO LOTE INVLIDO');
   INCLUI_ERRCNABP ('275', 'AI', 'CDIGO DE SEGMENTO DE DETALHE INVLIDO');
   INCLUI_ERRCNABP ('275', 'AJ', 'TIPO DE MOVIMENTO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AK', 'CDIGO DA CMARA DE COMPENSAO DO BANCO FAVORECIDO/DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AL', 'CDIGO DO BANCO FAVORECIDO OU DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AM', 'AGNCIA MANTENEDORA DA CONTA CORRENTE DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP ('275', 'AN', 'CONTA CORRENTE/DV DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AO', 'NOME DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('275', 'AP', 'DATA LANAMENTO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AQ', 'TIPO/QUANTIDADE DA MOEDA INVLIDO');
   INCLUI_ERRCNABP ('275', 'AR', 'VALOR DO LANAMENTO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AS', 'AVISO AO FAVORECIDO - IDENTIFICAO INVLIDA');
   INCLUI_ERRCNABP ('275', 'AT', 'TIPO/NMERO DE INSCRIO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AU', 'LOGRADOURO DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('275', 'AV', 'N DO LOCAL DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('275', 'AW', 'CIDADE DO FAVORECIDO NO INFORMADA ');
   INCLUI_ERRCNABP ('275', 'AX', 'CEP/COMPLEMENTO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('275', 'AY', 'SIGLA DO ESTADO DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP ('275', 'AZ', 'CDIGO/NOME DO BANCO DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('275', 'BA', 'CDIGO/NOME DA AGNCIA DEPOSITRIA NO INFORMADO');
   INCLUI_ERRCNABP ('275', 'BB', 'SEU NMERO INVLIDO');
   INCLUI_ERRCNABP ('275', 'BC', 'NOSSO NMERO INVLIDO');
   INCLUI_ERRCNABP ('275', 'BD', 'INCLUSO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP ('275', 'BE', 'ALTERAO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP ('275', 'BF', 'EXCLUSO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP ('275', 'BG', 'AGNCIA/CONTA IMPEDIDA LEGALMENTE');
   INCLUI_ERRCNABP ('275', 'CA', 'CDIGO DE BARRAS - CDIGO DO BANCO INVLIDO');
   INCLUI_ERRCNABP ('275', 'CB', 'CDIGO DE BARRAS - CDIGO DA MOEDA INVLIDO');
   INCLUI_ERRCNABP ('275', 'CC', 'CDIGO DE BARRAS - DGITO VERIFICADOR GERAL INVLIDO');
   INCLUI_ERRCNABP ('275', 'CD', 'CDIGO DE BARRAS - VALOR DO TTULO INVLIDO');
   INCLUI_ERRCNABP ('275', 'CE', 'CDIGO DE BARRAS - CAMPO LIVRE INVLIDO');
   INCLUI_ERRCNABP ('275', 'CF', 'VALOR DO DOCUMENTO INVLIDO');
   INCLUI_ERRCNABP ('275', 'CG', 'VALOR DO ABATIMENTO INVLIDO');
   INCLUI_ERRCNABP ('275', 'CH', 'VALOR DO DESCONTO INVLIDO');
   INCLUI_ERRCNABP ('275', 'CI', 'VALOR DE MORA INVLIDO');
   INCLUI_ERRCNABP ('275', 'CJ', 'VALOR DA MULTA INVLIDO');
   INCLUI_ERRCNABP ('275', 'CK', 'VALOR DO IR INVLIDO');
   INCLUI_ERRCNABP ('275', 'CL', 'VALOR DO ISS INVLIDO');
   INCLUI_ERRCNABP ('275', 'CM', 'VALOR DO IOF INVLIDO');
   INCLUI_ERRCNABP ('275', 'CN', 'VALOR DE OUTRAS DEDUES INVLIDO');
   INCLUI_ERRCNABP ('275', 'CO', 'VALOR DE OUTROS ACRSCIMOS INVLIDO');
   INCLUI_ERRCNABP ('275', 'CP', 'VALOR DO INSS INVLIDO');
   INCLUI_ERRCNABP ('275', 'TA', 'LOTE NO ACEITO - TOTAIS DO LOTE COM DIFERENA');
   INCLUI_ERRCNABP ('275', 'YA', 'TTULO NO ENCONTRADO');
   INCLUI_ERRCNABP ('275', 'YB', 'IDENTIFICADOR REGISTRO OPCIONAL INVLIDO');
   INCLUI_ERRCNABP ('275', 'YC', 'CDIGO PADRO INVLIDO');
   INCLUI_ERRCNABP ('275', 'YD', 'CDIGO DE OCORRNCIA INVLIDO');
   INCLUI_ERRCNABP ('275', 'YE', 'COMPLEMENTO DE OCORRNCIA INVLIDO');
   INCLUI_ERRCNABP ('275', 'YF', 'ALEGAO J INFORMADA');
   COMMIT;
END;
/
BEGIN
-- BANCO SAFRA 422

   INCLUI_ERRCNABP ('422', '076', 'BLOQUEIO JUDICIAL  SALDO INSULFICIENTE');
   INCLUI_ERRCNABP ('422', '099', 'REGISTRO CADASTRO DE CLIENTE NAO ENCONTRADO NO SCC');
   INCLUI_ERRCNABP ('422', '100', 'CONTA CORRENTE NO CADASTRADA');
   INCLUI_ERRCNABP ('422', '112', 'TRANSAO INVLIDA - J CADASTRADA');
   INCLUI_ERRCNABP ('422', '114', 'ALTERAO INVLIDA - COMPROMISSO LIBERADO PARA PAGAMENTO');
   INCLUI_ERRCNABP ('422', '119', 'EXCLUSO INVALIDA  CMP LIBERADO PARA PAGAMENTO');
   INCLUI_ERRCNABP ('422', '130', 'COMPROMISSO COM PAGAMENTO J EFETUADO');
   INCLUI_ERRCNABP ('422', '132', 'FORNECEDOR NO CADASTRADO');
   INCLUI_ERRCNABP ('422', '139', 'COMPROMISSO NO CADASTRADO');
   INCLUI_ERRCNABP ('422', '145', 'AUTORIZAO INVLIDA PRE. CONFERNCIA MSG.');
   INCLUI_ERRCNABP ('422', '148', 'TRANSAO INVLIDA  - REDIGITAO PEDENTE');
   INCLUI_ERRCNABP ('422', '157', 'AGNCIA C/C INVLIDA');
   INCLUI_ERRCNABP ('422', '195', 'COB AGNCIA DBITO  = AGNCIA P/ PAGTO');
   INCLUI_ERRCNABP ('422', '196', 'COB DATA PAGTO = DATA VENCIMENTO');
   INCLUI_ERRCNABP ('422', '197', 'DATA PAGTO FERIADO AGNCIA PAGTO OU AGNCIA DBITO');
   INCLUI_ERRCNABP ('422', '198', 'COMPROMISSO J DEBITADO DO CLIENTE');
   INCLUI_ERRCNABP ('422', '200', 'NOME/ENDEREO DO FORNECEDOR OBRIGATRIO');
   INCLUI_ERRCNABP ('422', '201', 'CD. DO FORNECEDOR DEVE SER NUMRICO');
   INCLUI_ERRCNABP ('422', '202', 'CD. DO FORNECEDOR COM DGITO INVLIDO');
   INCLUI_ERRCNABP ('422', '203', 'CGC(CNPJ)/CPF DEVE SER NUMRICO');
   INCLUI_ERRCNABP ('422', '204', 'CGC(CNPJ)/CPF COM DGITO INVLIDO');
   INCLUI_ERRCNABP ('422', '206', 'BANCO PARA CRDITO DEVE SER NUMRICO');
   INCLUI_ERRCNABP ('422', '207', 'AGNCIA PARA CRDITO DEVE SER NUMRICO');
   INCLUI_ERRCNABP ('422', '210', 'BCO PARA CRED NO CADASTRADO');
   INCLUI_ERRCNABP ('422', '213', 'VOLUME J PROCESSADO, DADOS DUPLICADOS');
   INCLUI_ERRCNABP ('422', '216', 'COB DATA PAGTO INVLIDA');
   INCLUI_ERRCNABP ('422', '217', 'COMPROMISSO BLOQUEADO POR INSUFICINCIA DE SALDO');
   INCLUI_ERRCNABP ('422', '240', 'AUTORIZAAO VIA ARQUIVO NO TERMITIDA');
   INCLUI_ERRCNABP ('422', '250', 'DATA DE VENCIMENTO OU VALOR INVLIDO');
   INCLUI_ERRCNABP ('422', '251', 'DATA DE VENCIMENTO INVLIDA') ;
   INCLUI_ERRCNABP ('422', '252', 'TIPO DE PAGAMENTO INVLIDO');
   INCLUI_ERRCNABP ('422', '253', 'DATA DE VENCIMENTO INVLIDA');
   INCLUI_ERRCNABP ('422', '254', 'BANCO PORTADOR DO TTULO DEVE SER NUMRICO');
   INCLUI_ERRCNABP ('422', '255', 'AGNCIA PARA PAGAMENTO INVLIDA');
   INCLUI_ERRCNABP ('422', '258', 'TIPO DE DOCUMENTO DO COMPROMISSO NO CADASTRADO');
   INCLUI_ERRCNABP ('422', '259', 'MOEDA NO CADASTRADA');
   INCLUI_ERRCNABP ('422', '260', 'DATA DE PAGAMENTO MENOR OU IGUAL A DATA DE HOJE');
   INCLUI_ERRCNABP ('422', '261', 'BANCO PORTADOR DO TTULO NO CADASTRADO');
   INCLUI_ERRCNABP ('422', '262', 'AGNCIA PARA PAGAMENTO NO CADASTRADA');
   INCLUI_ERRCNABP ('422', '264', 'DADOS INCLOMPLETOS PARA PAGAMENTO');
   INCLUI_ERRCNABP ('422', '265', 'DADOS INCOMPLETOS PARA PAGAMENTO COM DOC');
   INCLUI_ERRCNABP ('422', '266', 'DADOS INCOMPLETOS PARA PAGAMENTO EM C/C');
   INCLUI_ERRCNABP ('422', '269', 'COMPROMISSO VERUS AGNCIA PARA PAGAMENTO INCOMPLETO');
   INCLUI_ERRCNABP ('422', '271', 'COMPROMISSO J AUTORIZADO OU BLOQUEADO');
   INCLUI_ERRCNABP ('422', '303', 'DATA INVLIDA');
   INCLUI_ERRCNABP ('422', '304', 'MOVIMENTO SEM HEADER (AGENCIA/CONTA DIFERENTE ENTRE HEADER E DETALHE)');
   INCLUI_ERRCNABP ('422', '312', 'NMERO DO DOCUMENTO (COMPROMISSO) INVLIDO');
   INCLUI_ERRCNABP ('422', '313', 'COMPROMISSO J CADASTRADO');
   INCLUI_ERRCNABP ('422', '314', 'CMARA DE COMPENSAO INVLIDA');
   INCLUI_ERRCNABP ('422', '315', 'VALOR DO ABATIMENTO INVLIDO');
   INCLUI_ERRCNABP ('422', '316', 'VALOR DO JURO/ MULTA INVLIDO');
   INCLUI_ERRCNABP ('422', '317', 'C/C DEVE SER NUMRICA');
   INCLUI_ERRCNABP ('422', '323', 'CDIGO DE INSTRUO INVLIDO');
   INCLUI_ERRCNABP ('422', '324', 'AGNCIA/CLIENTE EST DIFERENTE DO REGISTRO HEADER');
   INCLUI_ERRCNABP ('422', '325', 'FALTA REGISTRO NUMRICO  XXXX');
   INCLUI_ERRCNABP ('422', '326', 'REGISTRO FORA DE ORDEM');
   INCLUI_ERRCNABP ('422', '327', 'NUMRICO DO REGISTRO DEVE SER NUMRICO');
   INCLUI_ERRCNABP ('422', '328', 'CLIENTE  DIFERE EM RELAO ');
   INCLUI_ERRCNABP ('422', '331', 'VALOR AUTORIZADO INVLIDO');
   INCLUI_ERRCNABP ('422', '332', 'COMPROMISSO INVLIDO');
   INCLUI_ERRCNABP ('422', '333', 'COMPROMISSO NO PODE SER BLOQUEADO');
   INCLUI_ERRCNABP ('422', '334', 'COMPROMISSO NO PODE SER DESBLOQUEADO');
   INCLUI_ERRCNABP ('422', '335', 'CDIGO DE ALEGAO INVLIDO');
   INCLUI_ERRCNABP ('422', '336', 'DESCRIO DE ALEGAO INVLIDA');
   INCLUI_ERRCNABP ('422', '337', 'CLIENTE INVLIDO');
   INCLUI_ERRCNABP ('422', '347', 'VALOR AUTORIZADO NO NUMERICO');
   INCLUI_ERRCNABP ('422', '371', 'AGNCIA PARA CRDITO INVLIDA');
   INCLUI_ERRCNABP ('422', '375', 'AGNCIA/CONTA CORRENTE INVLIDA(TECBAN)');
   INCLUI_ERRCNABP ('422', '378', 'BANCO PORTADOR INVLIDO');
   INCLUI_ERRCNABP ('422', '379', 'BANCO DESTINO INVLIDO');
   INCLUI_ERRCNABP ('422', '382', 'COMPROMISSO DUPLICADO');
   INCLUI_ERRCNABP ('422', '536', 'LINHA DIGITVEL INVLIDA');
   INCLUI_ERRCNABP ('422', '537', 'REGISTRO REJEITADO NA CRITICA PREVIA');
   INCLUI_ERRCNABP ('422', '538', 'DATA INVLIDA PARA TIPO DE PAGAMENTO "CHQ"');
   INCLUI_ERRCNABP ('422', '588', 'CLIENTE NAO HABILITADO A CREDITAR CONTA SALARIO');
   INCLUI_ERRCNABP ('422', '598', 'FORNECEDOR INFORMADO NO  O TITULAR DA CONTA DESTINO');
   INCLUI_ERRCNABP ('422', '601', 'TIPO PAGAMENTO INVALIDO PARA CLIENTE SALARIO');
   INCLUI_ERRCNABP ('422', '602', 'PAGAMENTO CONTA SALARIO NAO PODE SER BLOQUEADO');
   INCLUI_ERRCNABP ('422', '603', 'TIPO DE DOCUMENTO EXCLUSIVO PARA CLIENTE CCS');
   INCLUI_ERRCNABP ('422', '604', 'TIPO DE DOCUMENTO DIFERENTE CCS');
   INCLUI_ERRCNABP ('422', '606', 'DIGITO DO CDIGO DE BARRAS INVLIDO');
   INCLUI_ERRCNABP ('422', '607', 'CLIENTE CREDITA SOMENTE CONTA SALARIO');
   INCLUI_ERRCNABP ('422', '654', 'TED INFERIOR AO VALOR MNIMO');
   INCLUI_ERRCNABP ('422', '632', 'CONTA INVESTIMENTO DE OUTRA TITULARIDADE');
   INCLUI_ERRCNABP ('422', '634', 'CONTA DESTINO NO  CONTA DE INVESTIMENTO');
   INCLUI_ERRCNABP ('422', '636', 'NO PERMITIDO. VALOR ACIMA DO LIMITE');
   INCLUI_ERRCNABP ('422', '639', 'TIPO DE DOC IGUAL DOC PARA CCI');
   INCLUI_ERRCNABP ('422', '640', 'AGNCIA OU CONTA INVESTIMENTO INVALIDA');
   INCLUI_ERRCNABP ('422', '650', 'INCLUSO INVAIDA PARA CAB');
   INCLUI_ERRCNABP ('422', '651', 'TED APS O HORRIO LIMITE (APS 17 HRS)');
   INCLUI_ERRCNABP ('422', '654', 'TED INFERIOR AO VALOR MINIMO');
   INCLUI_ERRCNABP ('422', '782', 'BANCO NO OPERANTE');
   INCLUI_ERRCNABP ('422', '786', 'REGISTRO NO ENCONTRADO NO SPB');
   INCLUI_ERRCNABP ('422', '813', 'CLENTE NO CRDITA CM');
   INCLUI_ERRCNABP ('422', '860', 'BANCO DE DESTINO INVALIDO PARA TED');
   INCLUI_ERRCNABP ('422', '875', 'CONTA BI NO ACEITA FAVORECIDO PF');
   INCLUI_ERRCNABP ('422', '876', 'FAVORECIDO DEVE SER DIFERENTE DE INSTITUIO FINANCEIRA (BI)');
   INCLUI_ERRCNABP ('422', '882', 'CONTAS ORIGEM E DESTINO NO SO IGUAIS');
   INCLUI_ERRCNABP ('422', '883', 'CONTA DESTINO NO PERTENCE AO TITULAR DA CCI');
   COMMIT;
END;
/
BEGIN
   -- BANCO UNIBANCO 409

   INCLUI_ERRCNABP ('409', '5301', 'CONTA CORRENTE DA EMPRESA NO NUMRICA, IGUAL A ZEROS, OU DGITO NO NUMRICO');
   INCLUI_ERRCNABP ('409', '5302', 'AGNCIA DA EMPRESA NO NUMRICA, IGUAL A ZEROS OU NO CADASTRADA NO UBB');
   INCLUI_ERRCNABP ('409', '5303', 'DGITO DA CONTA DA EMPRESA DIVERGENTE OU IGUAL A ZERO');
   INCLUI_ERRCNABP ('409', '5304', 'CONTA CORRENTE DA EMPRESA NO CADASTRADA NO UBB');
   INCLUI_ERRCNABP ('409', '5305', 'BANCO DO FAVORECIDO INVLIDO.NO NUMRICO, IGUAL A ZERO, NO CADASTRADO NO UBB OU TRATA-SE DE PAGAMENTO DE TTULO DE OUTRO BANCO (TIPO SERVIO "9") E O BANCO EST IGUAL A 409(UBB) ');
   INCLUI_ERRCNABP ('409', '5306', 'AGNCIA DO FAVORECIDO/DEBITADO INVLIDA OU INATIVA');
   INCLUI_ERRCNABP ('409', '5307', 'DGITO DA AGNCIA DO FAVORECIDO/DEBITADO IGUAL A BRANCOS OU NO NUMRICO');
   INCLUI_ERRCNABP ('409', '5308', 'C/C DO FAVORECIDO/DEBITADO NO NUMRICA OU IGUAL A ZEROS');
   INCLUI_ERRCNABP ('409', '5309', 'DGITO DA CONTA DO FAVORECIDO/DEBITADO NO NUMRICO OU IGUAL A ZEROS');
   INCLUI_ERRCNABP ('409', '5310', 'MEIO DE REPASSE INVLIDO - CONTATAR CENTRAL DE ATENDIMENTO');
   INCLUI_ERRCNABP ('409', '5311', 'BANCO DO FAVORECIDO/DEBITADO INEXISTENTE NA TABELA DE BANCOS');
   INCLUI_ERRCNABP ('409', '5312', 'AGNCIA FAVORECIDO/DEBITADO INEXISTENTE NO CADASTRO DE UNIDADES DO UBB');
   INCLUI_ERRCNABP ('409', '5313', 'EMISSO DE AVISO DIFERENTE DE 0,1 OU 2');
   INCLUI_ERRCNABP ('409', '5314', 'TIPO DE OPERAO DIFERENTE DE "5"-CRDITO OU "6"-DBITO');
   INCLUI_ERRCNABP ('409', '5315', 'TIPO DE SERVIO INVLIDO');
   INCLUI_ERRCNABP ('409', '5318', 'VALOR DA TRANSAO NO NUMRICO OU IGUAL A ZEROS');
   INCLUI_ERRCNABP ('409', '5319', 'VALOR SUPERIOR A TRAVA CONTRATADA.CONTATE SE GERENTE DE NEGCIOS E SERVIOS ELETRNICOS');
   INCLUI_ERRCNABP ('409', '5320', 'AGNCIA/ CONTA INVLIDA-PAGAMENTO DARF/GPS');
   INCLUI_ERRCNABP ('409', '5321', 'DATA DE GRAVAO INEXISTENTE');
   INCLUI_ERRCNABP ('409', '5322', 'DATA DE CRDITO/DBITO NO NUMRICA OU IGUAL A ZEROS');
   INCLUI_ERRCNABP ('409', '5323', 'DATA DE DBITO/CRDITO INVLIDA - PAGAMENTO DARF/GPS');
   INCLUI_ERRCNABP ('409', '5324', 'DATA CRDITO/DBITO INFERIOR  DATA PROCESSAMENTO(DE ACORDO COM O FLOAT)');
   INCLUI_ERRCNABP ('409', '5325', 'DATA DE CRDITO/DBITO INVLIDA.PARA TTULOS DE OUTROS BANCOS, SUPERIOR A 15 DIAS');
   INCLUI_ERRCNABP ('409', '5326', 'NOME DO FAVORECIDO/DEBITADO INVLIDO OU EM BRANCO');
   INCLUI_ERRCNABP ('409', '5327', 'LOGRADOURO/ENDEREO EM BRANCO');
   INCLUI_ERRCNABP ('409', '5328', 'NOME DA CIDADE EM BRANCO');
   INCLUI_ERRCNABP ('409', '5329', 'DATA APURAO INVLIDA - PAGAMENTO DARF');
   INCLUI_ERRCNABP ('409', '5330', 'ESTADO INEXISTENTE');
   INCLUI_ERRCNABP ('409', '5331', 'CEP NO NUMRICO');
   INCLUI_ERRCNABP ('409', '5332', 'NOME DA AGNCIA DO FAVORECIDO/DEBITADO EM BRANCO.SOMENTE PARA DOC EM QUE O CLIENTE INFORMA A PRAA DE COMPENSAO');
   INCLUI_ERRCNABP ('409', '5334', 'TIPO DOCUMENTO INVLIDO - PAGAMENTO DARF');
   INCLUI_ERRCNABP ('409', '5335', 'PRAA DE COMPENSAO INEXISTENTE');
   INCLUI_ERRCNABP ('409', '5336', 'AMARRAO HORIZONTAL DIFERENTE DO CALCULADO EM (CONTA + VALOR)* OPERAO');
   INCLUI_ERRCNABP ('409', '5337', 'CLIENTE NO CADASTRADO PARA O TIPO DE SERVIO INFORMADO');
   INCLUI_ERRCNABP ('409', '5338', 'TIPO DE OPERAO "6" -DBITO E O BANCO NO  "409"(UBB)');
   INCLUI_ERRCNABP ('409', '5342', 'CONTA MOVIMENTO DO CLIENTE NO CADASTRADA PARA PAGAMENTOS DE OCT/CE');
   INCLUI_ERRCNABP ('409', '5343', 'CDIGO DA TRANSAO DO CVT INVLIDO, PARA PAGAMENTOS DE OCT/CE');
   INCLUI_ERRCNABP ('409', '5344', 'CEDENTE NO CADASTRADO NO UNIBANCO PARA OPERAR COM TRANSAES DE COBRANA ESPECIAL');
   INCLUI_ERRCNABP ('409', '5345', 'N. DE REFERNCIA DA COBRANA ESPECIAL INVLIDO');
   INCLUI_ERRCNABP ('409', '5346', 'DATA VENCIMENTO INVLIDA - PAGAMENTO DARF');
   INCLUI_ERRCNABP ('409', '5347', 'POSIO 220 A 234 - INVLIDA');
   INCLUI_ERRCNABP ('409', '5348', 'CEDENTE NO CADASTRADO NO UNIBANCO PARA OPERAR COM TRANSAES DE OCT');
   INCLUI_ERRCNABP ('409', '5349', 'TIPO DA SOLICITAO INVLIDO PARA PAGAMENTO ELETRNICO UNIBANCO(DIFERENTE DE 1 A 7)');
   INCLUI_ERRCNABP ('409', '5350', 'AGNCIA DOMICLIO INEXISTENTE PARA PAGAMENTO ELETRNICO UNIBANCO');
   INCLUI_ERRCNABP ('409', '5351', 'TIPO DE SERVIO NO AUTORIZADO PARA OPERAR COM PAGAMENTO ELETRNICO UNIBANCO');
   INCLUI_ERRCNABP ('409', '5352', 'NOSSO NMERO NO NUMRICO OU IGUAL A ZERO PARA ALTERAO, CANCELAMENTO OU EXCLUSO DE PAGAMENTOS(CD. DA OPERAO IGUAL A 2,3 OU 4');
   INCLUI_ERRCNABP ('409', '5353', 'NOSSO NMERO NO CADASTRADO P/ ALTERAO DE PAGTO');
   INCLUI_ERRCNABP ('409', '5354', 'NMERO DOCUMENTO INVLIDO - PAGAMENTO DARF/GPS');
   INCLUI_ERRCNABP ('409', '5355', 'CDIGO RECEITA INVLIDO - PAGAMENTO DARF/GPS');
   INCLUI_ERRCNABP ('409', '5356', 'NO  PERMITIDO A ALTERAO DE PAGAMENTO J AUTORIZADO OU A DATA DO PAGAMENTO SOLICITADO  IGUAL A DATA DO PROCESSAMENTO');
   INCLUI_ERRCNABP ('409', '5357', 'NO  PERMITIDO O CANCELAMENTO DE PAGAMENTO NO AUTORIZADO OU A DATA DO PAGAMENTO SOLICITADO  IGUAL A DATA DO PROCESSAMENTO');
   INCLUI_ERRCNABP ('409', '5358', 'NO  PERMITIDO EXCLUSO DE PGTO AUTORIZADO, PAGO OU INATIVO OU, DATA DO PAGAMENTO SOLICITADO IGUAL A DATA DO PAGAMENTO');
   INCLUI_ERRCNABP ('409', '5359', 'NO  PERMITIDO ALTERAO DE PAGAMENTO COM OS SEGUINTES DADOS IGUAIS AO ANTERIOR: CDIGO DA OPERAO , C/C DA EMPRESA E NOSSO NMERO');
   INCLUI_ERRCNABP ('409', '5360', 'NO  PERMITIDO CANCELAMENTO COM OS SEGUINTES DADOS IGUAIS AO ANTERIOR: CDIGO DA OPERAO, C/C DA EMPRESA E NOSSO NMERO');
   INCLUI_ERRCNABP ('409', '5361', 'NO  PERMITIDO EXCLUSO DE PAGTO COM OS SEGUINTES DADOS IGUAIS AO ANTERIOR CDIGO DA OPERAO, C/C DA EMPRESA E NOSSO NMERO');
   INCLUI_ERRCNABP ('409', '5362', 'A EMPRESA EST SOLICITANDO CRDITO PARA UM BENEFICIRIO DE PAGAMENTO ELETRNICO UNIBANCO, SEM ANTES TER SOLICITADO O SEU CADASTRAMENTO');
   INCLUI_ERRCNABP ('409', '5363', 'A EMPRESA EST SOLICITANDO A INCLUSO DE UM BENEFICIRIO J CADASTRADO NO PAGAMENTO ELETRNICO UNIBANCO');
   INCLUI_ERRCNABP ('409', '5364', 'SOLICITAO DE PAGAMENTO ELETRNICO UNIBANCO J EFETUADA ANTERIORMENTE');
   INCLUI_ERRCNABP ('409', '5365', 'CDIGO DE MOEDA NO ENCONTRADO PARA PAGAMENTO DE TTULO DE OUTRO BANCO');
   INCLUI_ERRCNABP ('409', '5366', 'NOSSO NMERO DO OUTRO BANCO NO INFORMADO(EM BRANCO), PARA PAGAMENTO DE TTULO DE OUTRO BANCO(TIPO SERVIO "6" OU "9")');
   INCLUI_ERRCNABP ('409', '5367', 'CDIGO DE EMPRESA NO NUMRICO OU IGUAL A ZEROS PARA PAGAMENTO ELETRNICO UNIBANCO');
   INCLUI_ERRCNABP ('409', '5368', 'VALOR RECEITA INVLIDO.PAGAMENTO DARF');
   INCLUI_ERRCNABP ('409', '5369', 'DGITO DO NMERO DO BENEFICIRIO DIFERENTE DO CALCULADO PARA PAGAMENTO ELETRNICO UNIBANCO/CARTO SAQUE');
   INCLUI_ERRCNABP ('409', '5370', 'CLIENTE NO CADASTRADO NO UNIBANCO PARA OPERAR COM TRANSAES DE CONTAS A RECEBER');
   INCLUI_ERRCNABP ('409', '5371', 'CONTA DO CLIENTE NO NUMRICO, IGUAL A ZEROS OU INEXISTENTE');
   INCLUI_ERRCNABP ('409', '5372', 'NO  POSSVEL EFETUAR O PAGAMENTO PARA ESTA DATA, HORRIO LIMITE PARA ENVIO DE DOC J EXPIRADO.PROCESSAMENTO J EFETUADO');
   INCLUI_ERRCNABP ('409', '5373', 'NO  POSSVEL EFETUAR O PAGAMENTO PARA ESTA DATA, HORRIO LIMITE EXPIRADO.PROCESSAMENTO J EFETUADO ');
   INCLUI_ERRCNABP ('409', '5374', 'CONTA CORRENTE NO CADASTRADA');
   INCLUI_ERRCNABP ('409', '5375', 'CDIGO DO IPTE INVLIDO');
   INCLUI_ERRCNABP ('409', '5376', 'CDIGO DE BARRAS INVLIDO');
   INCLUI_ERRCNABP ('409', '5377', 'AGENDAMENTO NO PERMITIDO');
   INCLUI_ERRCNABP ('409', '5378', 'OPERAO INVLIDA');
   INCLUI_ERRCNABP ('409', '5379', 'REFERNCIA INVLIDA - PAGAMENTO DARF');
   INCLUI_ERRCNABP ('409', '5380', 'AUTORIZAO NO PERMITIDA');
   INCLUI_ERRCNABP ('409', '5381', 'TTULO J AUTORIZADO');
   INCLUI_ERRCNABP ('409', '5382', 'AGNCIA DOMICLIO INVLIDA');
   INCLUI_ERRCNABP ('409', '5384', 'NOTA FISCAL INVLIDA');
   INCLUI_ERRCNABP ('409', '5385', 'CNPJ / CPF INVLIDO');
   INCLUI_ERRCNABP ('409', '5388', 'PERCENTUAL RECEITA INVLIDO - PAGAMENTO DARF');
   INCLUI_ERRCNABP ('409', '5389', 'VALOR PRINCIPAL INVLIDO - PAGAMENTO DARF/GPS');
   INCLUI_ERRCNABP ('409', '5394', 'VALOR JUROS INVLIDO - PAGAMENTO DARF');
   INCLUI_ERRCNABP ('409', '5395', 'VALOR OUTROS INVLIDO - PAGAMENTO GPS');
   INCLUI_ERRCNABP ('409', '5396', 'VALOR TOTAL INVLIDO - PAGAMENTO DARF/GPS');
   INCLUI_ERRCNABP ('409', '5397', 'DATA COMPETNCIA INVLIDA - PAGAMENTO GPS');
   INCLUI_ERRCNABP ('409', '5399', 'CDIGO DA EMPRESA DIFERENTE DO CADASTRADO.O CLIENTE NO EST CADASTRADO PARA TRABALHAR COM CARTO SAQUE');
   INCLUI_ERRCNABP ('409', '5438', 'NO EXISTE CONTA CORRENTE');
   INCLUI_ERRCNABP ('409', '5439', 'SEM SALDO');
   INCLUI_ERRCNABP ('409', '5440', 'C/C - AGNCIA ENCERRADA');
   INCLUI_ERRCNABP ('409', '5441', 'C/C - AGNCIA INVLIDA');
   INCLUI_ERRCNABP ('409', '5442', 'C/C - AGNCIA INEXISTENTE NO CADASTRO DE AGNCIAS');
   INCLUI_ERRCNABP ('409', '5470', 'CONTA ENCERRADA');
   INCLUI_ERRCNABP ('409', '5471', 'BLOQUEIO JUDICIAL');
   INCLUI_ERRCNABP ('409', '5472', 'TRANSFERNCIA INSUFICIENTE');
   INCLUI_ERRCNABP ('409', '5473', 'AGNCIA, CONTA CORRENTE OU NOME DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('409', '5474', 'DOC-D INVLIDO - CONTA POUPANA');
   INCLUI_ERRCNABP ('409', '5475', 'DOC-D INVLIDO - CGC/CPF INVLIDO');
   INCLUI_ERRCNABP ('409', '5476', 'MOEDA INVLIDA');
   INCLUI_ERRCNABP ('409', '5477', 'CLIENTE RECUSOU O CRDITO');
   INCLUI_ERRCNABP ('409', '5486', 'IDENTIFICAO DO CLIENTE VISA INVLIDO');
   INCLUI_ERRCNABP ('409', '5487', 'NOME DO CLIENTE VISA INVLIDO');
   INCLUI_ERRCNABP ('409', '5499', 'CONTATAR UNIBANCO INFORMANDO O CDIGO DO ERRO IDENTIFICADO.O PAGAMENTO NO EFETUADO, ENCONTRA-SE NO STATUS "A RECONFIRMAR"');
   COMMIT;
END;
/
BEGIN
   -- BANCO BANESPA  033

   INCLUI_ERRCNABP ('033', '00', 'LANAMENTO EFETUADO');
   INCLUI_ERRCNABP ('033', '01', 'LANAMENTO NO EFETUADO');
   INCLUI_ERRCNABP ('033', '02', 'LANAMENTO CANCELADO PELO CONVENIADO');
   INCLUI_ERRCNABP ('033', 'AA', 'CONTROLE INVLIDO');
   INCLUI_ERRCNABP ('033', 'AB', 'TIPO DE OPERAO INVLIDO');
   INCLUI_ERRCNABP ('033', 'AC', 'TIPO DE SERVIO INVLIDO');
   INCLUI_ERRCNABP ('033', 'AD', 'FORMA DE LANAMENTO INVLIDA');
   INCLUI_ERRCNABP ('033', 'AE', 'TIPO/NMERO DE INSCRIO INVLIDA');
   INCLUI_ERRCNABP ('033', 'AG', 'CONTA CORRENTE DO CONVENIADO(N.DA AGNCIA /N DA CONTA/DV)INVLIDA');
   INCLUI_ERRCNABP ('033', 'AH', 'NMERO SEQUENCIAL DO REGISTRO NO LOTE INVLIDO');
   INCLUI_ERRCNABP ('033', 'AI', 'CDIGO DE SEGMENTO DE DETALHE INVLIDO');
   INCLUI_ERRCNABP ('033', 'AJ', 'TIPO DE MOVIMENTO INVLIDO');
   INCLUI_ERRCNABP ('033', 'AK', 'CDIGO DA CMARA DE COMPENSAO DO BANCO DO FAVORECIDO/DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('033', 'AL', 'CDIGO DO BANCO DO FAVORECIDO OU DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('033', 'AM', 'AGNCIA MANTENEDORA DA CONTA CORRENTE DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP ('033', 'AN', 'CONTA CORRENTE/DV DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('033', 'AO', 'NOME DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('033', 'AP', 'DATA LANAMENTO INVLIDA');
   INCLUI_ERRCNABP ('033', 'AQ', 'TIPO/QUANTIDADE DA MOEDA INVLIDO');
   INCLUI_ERRCNABP ('033', 'AR', 'VALOR DO LANAMENTO INVLIDO');
   INCLUI_ERRCNABP ('033', 'AS', 'AVISO AO FAVORECIDO - IDENTIFICAO INVLIDA(INFORMATIVO)');
   INCLUI_ERRCNABP ('033', 'AT', 'TIPO/N DE INSCRIO DO FAVORECIDO NO SEGMENTO "B" INVLIDO');
   INCLUI_ERRCNABP ('033', 'AU', 'LOGRADOURO DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('033', 'AW', 'CIDADE DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('033', 'AX', 'CEP/ COMPLEMENTO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('033', 'AY', 'SIGLA DO ESTADO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('033', 'AZ', 'CDIGO/ NOME DO BANCO DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('033', 'BC', 'NOSSO NMERO INVLIDO');
   INCLUI_ERRCNABP ('033', 'BD', 'CONFIRMAO DE AGENDAMENTO DE COMPROMISSO');
   INCLUI_ERRCNABP ('033', 'CA', 'CDIGO DE BARRAS - CDIGO DO BANCO INVLIDO');
   INCLUI_ERRCNABP ('033', 'CB', 'CDIGO DE BARRAS - CDIGO DA MOEDA INVLIDO ');
   INCLUI_ERRCNABP ('033', 'CC', 'CDIGO DE BARRAS - DGITO VERIFICADOR GERAL INVLIDO');
   INCLUI_ERRCNABP ('033', 'CD', 'CDIGO DE BARRAS - VALOR DO TTULO INVLIDO');
   INCLUI_ERRCNABP ('033', 'CE', 'CDIGO DE BARRAS - CAMPO LIVRE INVLIDO');
   INCLUI_ERRCNABP ('033', 'CF', 'VALOR DO DOCUMENTO INFORMADO NO SEGMENTO "B" INVLIDO');
   INCLUI_ERRCNABP ('033', 'CG', 'VALOR DO ABATIMENTO INFORMADO NO SEGMENTO "B" INVLIDO ');
   INCLUI_ERRCNABP ('033', 'CH', 'VALOR DO DESCONTO INFORMADO NO SEGMENTO "B" INVLIDO');
   INCLUI_ERRCNABP ('033', 'CI', 'VALOR DA MORA INFORMADA NO SEGMENTO "B" INVLIDO');
   INCLUI_ERRCNABP ('033', 'CJ', 'VALOR DA MULTA INFORMADA NO SEGMENTO "B" INVLIDO');
   INCLUI_ERRCNABP ('033', 'HA', 'LOTE NO ACEITO');
   INCLUI_ERRCNABP ('033', 'HB', 'INSCRIO DA EMPRESA INVLIDA PARA O CONTRATO');
   INCLUI_ERRCNABP ('033', 'HC', 'CONVNIO COM A EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('033', 'HD', 'AGNCIA/ CONTA CORRENTE DA EMPRESA INEXISTENTE/ INVLIDA PARA CONTRATO');
   INCLUI_ERRCNABP ('033', 'HE', 'TIPO DE SERVIO INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('033', 'TA', 'LOTE NO ACEITO - TOTAIS DO LOTE COM DIFERENA');
   INCLUI_ERRCNABP ('033', 'XA', 'TIPO DE LANAMENTO = 50(GPS) E TIPO DE SERVIO DIFERENTE DE 20');
   INCLUI_ERRCNABP ('033', 'XB', 'TIPO DE LANAMENTO = 50(GPS) E NMERO DE INSCRIO DO CONTRIBUINTE IGUAL A ZEROS');
   INCLUI_ERRCNABP ('033', 'XC', 'CDIGO DO PAGAMENTO OU COMPETNCIA OU N DE INSCRIO NO INSS INVLIDO');
   INCLUI_ERRCNABP ('033', 'XD', 'BANCO DA CONTA CORRENTE DO FAVORECIDO DIFERENTE DE ZEROS');
   INCLUI_ERRCNABP ('033', 'XE', 'AGNCIA, DGITO AGNCIA, N DA CONTA, DGITO CONTA OU DGITO AGNCIA-CONTA NO NUMRICO OU DIFERENTE DE ZERO');
   INCLUI_ERRCNABP ('033', 'XF', 'CD.PAGTO.OU COMPET. NO NUMRICO OU = ZEROS.TIPO TRIBUTO DIFERENTE DE GPS');
   COMMIT;
END;
/
BEGIN
   -- BANCO DO BRASIL  001
   INCLUI_ERRCNABP ('001', 'HA', 'LOTE NO ACEITO');
   INCLUI_ERRCNABP ('001', 'HB', 'INSCRIO DA EMPRESA INVLIDA PARA O CONTRATO');
   INCLUI_ERRCNABP ('001', 'HC', 'CONVNIO COM A EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('001', 'HD', 'AGENCIA/CONTA DA EMPRESA INEXISTENTE/INVLIDA PARA O CONTRATO');
   INCLUI_ERRCNABP ('001', 'HE', 'TIPO DE SERVIO INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP ('001', 'HF', 'CONTA CORRENTE DA EMPRESA COM SALDO INSUFICIENTE');
   INCLUI_ERRCNABP ('001', 'HG', 'LOTE DE SERVIO FORA DE SEQUNCIA');
   INCLUI_ERRCNABP ('001', 'HH', 'LOTE DE SERVIO INVLIDO');
   INCLUI_ERRCNABP ('001', 'AA', 'CONTROLE INVLIDO');
   INCLUI_ERRCNABP ('001', 'AB', 'TIPO DE OPERAO INVLIDO');
   INCLUI_ERRCNABP ('001', 'AC', 'TIPO DE SERVIO INVLIDO');
   INCLUI_ERRCNABP ('001', 'AD', 'FORMA DE LANAMENTO INVLIDA');
   INCLUI_ERRCNABP ('001', 'AE', 'TIPO/NMERO DE INSCRIO INVLIDO');
   INCLUI_ERRCNABP ('001', 'AF', 'CDIGO DE CONVNIO INVLIDO');
   INCLUI_ERRCNABP ('001', 'AG', 'AGNCIA/CONTA CORRENTE/DV INVLIDO');
   INCLUI_ERRCNABP ('001', 'AH', 'N SEQUENCIAL DO REGISTRO NO LOTE INVLIDO');
   INCLUI_ERRCNABP ('001', 'AI', 'CDIGO DE SEGMENTO DE DETALHE INVLIDO');
   INCLUI_ERRCNABP ('001', 'AJ', 'TIPO DE MOVIMENTO INVLIDO');
   INCLUI_ERRCNABP ('001', 'AK', 'CDIGO DA CAMARA DE COMPENSAO DO BANCO DO FAVORECIDO DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('001', 'AL', 'CDIGO DO BANCO DO FAVORECIDO OU DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('001', 'AM', 'AGNCIA MANTENEDORA DA CONTA C/C DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP ('001', 'AN', 'CONTA CORRENTE/DV DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('001', 'AO', 'NOME DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('001', 'AP', 'DATA LANAMENTO INVLIDA');
   INCLUI_ERRCNABP ('001', 'AQ', 'TIPO/QUANTIDADE DA MOEDA INVLIDO');
   INCLUI_ERRCNABP ('001', 'AR', 'VALOR DO LANAMENTO INVLIDO');
   INCLUI_ERRCNABP ('001', 'AS', 'AVISO AO FAVORECIDO - IDENTIFICAO INVLIDA');
   INCLUI_ERRCNABP ('001', 'AT', 'TIPO/NUMERO DE INSCRIO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('001', 'AU', 'LOGRADOURO DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('001', 'AV', 'N DO LOCAL DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP ('001', 'AW', 'CIDADE DO FAVORECIDO NO INFORMADA');
   INCLUI_ERRCNABP ('001', 'AX', 'CEP/COMPLEMENTO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP ('001', 'AY', 'SIGLA DO ESTADO DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP ('001', 'AZ', 'CDIGO/NOME DO BANCO DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP ('001', 'BA', 'CDIGO/NOME DA AGNCIA DEPOSITRIA NO INFORMADO');
   INCLUI_ERRCNABP ('001', 'BB', 'SEU NMERO INVLIDO');
   INCLUI_ERRCNABP ('001', 'BC', 'NOSSO NMERO INVLIDO');
   INCLUI_ERRCNABP ('001', 'BD', 'CONFIRMAO DE PAGAMENTO AGENDADO');
   INCLUI_ERRCNABP ('001', 'BE', 'CPF/CGC DO CREDITADO NO CORRESPONDE A AGNCIA /CONTA INFORMADAS');
   INCLUI_ERRCNABP ('001', 'CA', 'CDIGO DE BARRAS - CDIGO DO BANCO INVLIDO');
   INCLUI_ERRCNABP ('001', 'CB', 'CDIGO DE BARRAS - CDIGO DA MOEDA INVLIDO ');
   INCLUI_ERRCNABP ('001', 'CC', 'CDIGO DE BARRAS - DGITO VERIFICADOR GERAL INVLIDO');
   INCLUI_ERRCNABP ('001', 'CD', 'CDIGO DE BARRAS - VALOR DO TTULO INVLIDO');
   INCLUI_ERRCNABP ('001', 'CE', 'CDIGO DE BARRAS - CAMPO LIVRE INVLIDO');
   INCLUI_ERRCNABP ('001', 'CF', 'VALOR DO DOCUMENTO INVLIDO');
   INCLUI_ERRCNABP ('001', 'CG', 'VALOR DO ABATIMENTO INVLIDO ');
   INCLUI_ERRCNABP ('001', 'CH', 'VALOR DO DESCONTO INVLIDO');
   INCLUI_ERRCNABP ('001', 'CI', 'VALOR DE MORA INVLIDO');
   INCLUI_ERRCNABP ('001', 'CJ', 'VALOR DA MULTA INVLIDO');
   INCLUI_ERRCNABP ('001', 'CK', 'VALOR DO IR INVLIDO');
   INCLUI_ERRCNABP ('001', 'CL', 'VALOR DO ISS INVLIDO');
   INCLUI_ERRCNABP ('001', 'CM', 'VALOR DO IOF INVLIDO');
   INCLUI_ERRCNABP ('001', 'CN', 'VALOR DE OUTRAS DEDUES INVLIDO');
   INCLUI_ERRCNABP ('001', 'CO', 'VALOR DE OUTROS ACRSCIMOS INVLIDO');
   INCLUI_ERRCNABP ('001', 'TA', 'LOTE NO ACEITO - TOTAIS DO LOTE COM DIFERENA');
   COMMIT;
END;
/
BEGIN
   -- BANCO DE BOSTON 479

   INCLUI_ERRCNABP ('479', '100', 'CONTA-CORRENTE NO CADASTRADA');
   INCLUI_ERRCNABP ('479', '104', 'CDIGO BANCO NO CADASTRADO');
   INCLUI_ERRCNABP ('479', '105', 'CDIGO AGNCIA NO CADASTRADO');
   INCLUI_ERRCNABP ('479', '106', 'CDIGO CLIENTE NO CADASTRADO');
   INCLUI_ERRCNABP ('479', '112', 'TRANSAO INVLIDA - J CADASTRADO');
   INCLUI_ERRCNABP ('479', '130', 'COMPROMISSO COM PAGAMENTO J EFETUADO');
   INCLUI_ERRCNABP ('479', '132', 'CDIGO FORNECEDOR NO CADASTRADO');
   INCLUI_ERRCNABP ('479', '133', 'DADOS INCOMPLETOS OU INVLIDOS');
   INCLUI_ERRCNABP ('479', '134', 'DADOS INCOMPLETOS REFERENTE AO TIPO DE PAGAMENTO');
   INCLUI_ERRCNABP ('479', '137', 'NUMERO DO DOCUMENTO ESTA DIFERENTE');
   INCLUI_ERRCNABP ('479', '139', 'COMPROMISSO NO CADASTRADO');
   INCLUI_ERRCNABP ('479', '142', 'DATA DE BAIXA INCOMPATIVEL COM DATA DE PAGTO');
   INCLUI_ERRCNABP ('479', '150', 'CLIENTE NO CADASTRADO EM BASES GERAIS');
   INCLUI_ERRCNABP ('479', '151', 'CLIENTE NO CADASTRADO PARA PAYMENTS EM BASES GERAIS');
   INCLUI_ERRCNABP ('479', '152', 'CLIENTE NO CADASTRADO NO RB-PES/RB-CLI :CONTATAR SISTEMAS');
   INCLUI_ERRCNABP ('479', '156', 'PONTO DE VENDA NO CADASTRADO');
   INCLUI_ERRCNABP ('479', '157', 'AGNCIA C/C INVLIDA');
   INCLUI_ERRCNABP ('479', '158', 'NUMERO C/C INVLIDO');
   INCLUI_ERRCNABP ('479', '159', 'COD ENDERECO PARA CORRESPONDENCIA INVLIDO');
   INCLUI_ERRCNABP ('479', '161', 'CAIXA POSTAL NO INFORMADA');
   INCLUI_ERRCNABP ('479', '162', 'CAIXA POSTAL INTERNA NO INFORMADA');
   INCLUI_ERRCNABP ('479', '166', 'OPO DE CGC INVLIDA');
   INCLUI_ERRCNABP ('479', '181', 'TIPO DE DOCUMENTO INVLIDO');
   INCLUI_ERRCNABP ('479', '182', 'FORNECEDOR NO POSSUI CONVENIO PARA COBRANCA');
   INCLUI_ERRCNABP ('479', '193', 'BCO P/ PAGAMENTO NO E BANCO CONVENIADO');
   INCLUI_ERRCNABP ('479', '197', 'DATA PAGTO E FERIADO NA SUC PAGTO OU SUC DE DEBITO');
   INCLUI_ERRCNABP ('479', '198', 'COMPROMISSO J FOI DEBITADO DO CLIENTE');
   INCLUI_ERRCNABP ('479', '200', 'NOME E ENDERECO DE FORNECEDOR OBRIGATORIOS');
   INCLUI_ERRCNABP ('479', '201', 'COD FORNECEDOR NO NUMERICO');
   INCLUI_ERRCNABP ('479', '202', 'COD FORNECEDOR C/DIGITO INVLIDO');
   INCLUI_ERRCNABP ('479', '203', 'CGC/CPF NO NUMERICO');
   INCLUI_ERRCNABP ('479', '204', 'CGC/CPF C/DIGITO INVLIDO');
   INCLUI_ERRCNABP ('479', '206', 'BANCO P/CREDITO NO NUMERICO');
   INCLUI_ERRCNABP ('479', '207', 'AGNCIA P/CREDITO NO NUMERICA');
   INCLUI_ERRCNABP ('479', '208', 'AGNCIA DO BOSTON NO ESTA CADASTRADA');
   INCLUI_ERRCNABP ('479', '210', 'BANCO P/CREDITO NO ESTA CADASTRADO');
   INCLUI_ERRCNABP ('479', '211', 'AGNCIA/CONTA DO BOSTON NO ESTA CADASTRADA');
   INCLUI_ERRCNABP ('479', '212', 'CLIENTE NO TROCA FITA DE PAYMENTS');
   INCLUI_ERRCNABP ('479', '213', 'ARQUIVO J PROCESSADO');
   INCLUI_ERRCNABP ('479', '214', 'CONVENIO NO CADASTRADO PARA AGNCIA');
   INCLUI_ERRCNABP ('479', '216', 'DATA VENCIMENTO INVLIDA PARA PAGTO EM "COB"');
   INCLUI_ERRCNABP ('479', '221', 'REGISTRO DE REDIGITAO NO CADASTRADO');
   INCLUI_ERRCNABP ('479', '223', 'AGNCIA DE PAGAMENTO COM CONTEUDO NO NUMERICO');
   INCLUI_ERRCNABP ('479', '233', 'AGNCIA INVLIDA - NO IMPLANTADA PAYMENTS');
   INCLUI_ERRCNABP ('479', '235', 'CLIENTE NO AUTORIZADO CADASTRAR PAGTO HOJE');
   INCLUI_ERRCNABP ('479', '236', 'HORARIO LIMITE P/CADASTRAR HOJE, ENCERRADA');
   INCLUI_ERRCNABP ('479', '240', 'CONVENIO NO ACEITA COMPR. C/ DATA PGTO > VENCTO');
   INCLUI_ERRCNABP ('479', '241', 'DATA PARA DEBITO FOI ALTERADA PARA PROXIMO DIA UTIL');
   INCLUI_ERRCNABP ('479', '242', 'DT.DEB.ALTERADA. FLOAT NO PODE SER > QUE CONVENIO OU > 3');
   INCLUI_ERRCNABP ('479', '247', 'OPO NO PERMITIDA,CONVENIO MODAL.VAREJO');
   INCLUI_ERRCNABP ('479', '250', 'DATA VENCIMENTO OU VALOR ZERADOS OU NO NUMERICOS');
   INCLUI_ERRCNABP ('479', '251', 'DATA VENCIMENTO INVLIDA');
   INCLUI_ERRCNABP ('479', '252', 'TIPO DE PAGAMENTO INVLIDO');
   INCLUI_ERRCNABP ('479', '253', 'DATA DE PAGAMENTO INVLIDA');
   INCLUI_ERRCNABP ('479', '254', 'BANCO PORTADOR DO TITULO NO NUMERICO');
   INCLUI_ERRCNABP ('479', '255', 'AGNCIA DE PAGAMENTO NO NUMERICA');
   INCLUI_ERRCNABP ('479', '258', 'TIPO DE DOCUMENTO DE COMPROMISSO NO CADASTRADO');
   INCLUI_ERRCNABP ('479', '259', 'MOEDA NO ESTA CADASTRADA');
   INCLUI_ERRCNABP ('479', '260', 'DATA DE PAGAMENTO NO PODE SER MENOR OU IGUAL DATA DE HOJE');
   INCLUI_ERRCNABP ('479', '261', 'BANCO PORTADOR NO ESTA CADASTRADO');
   INCLUI_ERRCNABP ('479', '262', 'AGNCIA DE PAGAMENTO NO ESTA CADASTRADA');
   INCLUI_ERRCNABP ('479', '263', 'AGNCIA DE PAGAMENTO NO E BANCO');
   INCLUI_ERRCNABP ('479', '264', 'DADOS INCOMPLETOS PARA PAGAMENTO');
   INCLUI_ERRCNABP ('479', '265', 'PAGTO EM DOC FALTANDO DADOS');
   INCLUI_ERRCNABP ('479', '266', 'PAGTO EM CC FALTANDO DADOS');
   INCLUI_ERRCNABP ('479', '267', 'PAGTO EM COB FALTANDO DADOS');
   INCLUI_ERRCNABP ('479', '270', 'CAMARA COMPENSAO NO EXISTE PARA O BANCO');
   INCLUI_ERRCNABP ('479', '271', 'COMPROMISSO DOMICILIO VAREJO SO ACEITA OCORRENCIA C04');
   INCLUI_ERRCNABP ('479', '276', 'TIPO PAGAMENTO INVLIDO P/COBRANCA VAREJO');
   INCLUI_ERRCNABP ('479', '281', 'NOTA FISCAL INVLIDA P/COBRANCA VAREJO ');
   INCLUI_ERRCNABP ('479', '282', 'VALOR NOTA DEVOLUO INVLIDO P/COB.VAREJO');
   INCLUI_ERRCNABP ('479', '285', 'TIPO DE COMPROMISSO INVLIDO P/COBRANCA VAREJO');
   INCLUI_ERRCNABP ('479', '299', 'CDIGO DE BARRA INVLIDO');
   INCLUI_ERRCNABP ('479', '300', 'ARQUIVO REMESSA SEM REGISTROS DE DETALHE  ');
   INCLUI_ERRCNABP ('479', '301', 'DATA RECEBIMENTO MENOR DATA REFERENCIA');
   INCLUI_ERRCNABP ('479', '302', 'NUMERO REGISTRO DO HEADER DIFERENTE 1');
   INCLUI_ERRCNABP ('479', '303', 'REGISTRO DE HEADER DO MOVIMENTO INVLIDO');
   INCLUI_ERRCNABP ('479', '304', 'MOVIMENTO SEM HEADER');
   INCLUI_ERRCNABP ('479', '305', 'REGISTRO DO ARQUIVO REMESSA NO IDENTIFICADO');
   INCLUI_ERRCNABP ('479', '306', 'VOLUME COM DADOS DUPLICADOS');
   INCLUI_ERRCNABP ('479', '312', 'NUMERO COMPROMISSO INVLIDO');
   INCLUI_ERRCNABP ('479', '313', 'COMPROMISSO J CADASTRADO');
   INCLUI_ERRCNABP ('479', '314', 'CAMARA COMPENSAO INVLIDA');
   INCLUI_ERRCNABP ('479', '315', 'VALOR ABATIMENTO INVLIDO');
   INCLUI_ERRCNABP ('479', '316', 'VALOR JUROS-MULTA INVLIDO');
   INCLUI_ERRCNABP ('479', '317', 'CONTA-CORRENTE NO NUMERICA');
   INCLUI_ERRCNABP ('479', '320', 'TITULO NO CAPTURADO DEVIDO ERRO CGC/CPF SACADO');
   INCLUI_ERRCNABP ('479', '321', 'TITULO CAPTURADO INDEVIDAMENTE ESTE CONVENIO');
   INCLUI_ERRCNABP ('479', '322', 'NO EXISTEM INSTRUCOES PARA ESSE TITULO');
   INCLUI_ERRCNABP ('479', '323', 'TIPO CDIGO INSCRIO INVLIDO');
   INCLUI_ERRCNABP ('479', '324', 'PTO VENDA/CONVENIO DIFERENTE DO HEADER');
   INCLUI_ERRCNABP ('479', '325', 'FALTA REGISTRO NUMERO XXXXX');
   INCLUI_ERRCNABP ('479', '326', 'REGISTRO FORA DE ORDEM');
   INCLUI_ERRCNABP ('479', '327', 'NUMERO REGISTRO NO NUMERICO');
   INCLUI_ERRCNABP ('479', '328', 'IDENTIFICAO CLIENTE DIFERENTE DO INICIAL');
   INCLUI_ERRCNABP ('479', '329', 'CDIGO OPERAO INVLIDO');
   INCLUI_ERRCNABP ('479', '330', 'CDIGO OCORRENCIA INVLIDO');
   INCLUI_ERRCNABP ('479', '331', 'VALOR AUTORIZADO INVLIDO');
   INCLUI_ERRCNABP ('479', '332', 'COMPROMISSO INVLIDO');
   INCLUI_ERRCNABP ('479', '333', 'COMPROMISSO NO PODE SER BLOQUEADO');
   INCLUI_ERRCNABP ('479', '334', 'COMPROMISSO NO PODE SER DESBLOQUEADO');
   INCLUI_ERRCNABP ('479', '335', 'CDIGO ALEGAO INVLIDO');
   INCLUI_ERRCNABP ('479', '336', 'DESCRIO DA ALEGAO INVLIDA');
   INCLUI_ERRCNABP ('479', '337', 'IDENTIFICAO DO CLIENTE INVLIDA');
   INCLUI_ERRCNABP ('479', '340', 'COMPR NO PODE SER EXCLUIDO - J DEBITADO');
   INCLUI_ERRCNABP ('479', '345', 'ALTERAO DE AVISO INVLIDA NO PROCESSAMENTO DA REMESSA');
   INCLUI_ERRCNABP ('479', '350', 'COMPR EM OUTRAS MOEDAS INVAL P LISTA DE DEBITO');
   INCLUI_ERRCNABP ('479', '355', 'VL. MOEDA NO CADASTRADO BASE GERAIS');
   INCLUI_ERRCNABP ('479', '357', 'NUMERO DO BORDERO INVLIDO');
   INCLUI_ERRCNABP ('479', '360', 'VAL. CHECKSUM INVLIDO');
   INCLUI_ERRCNABP ('479', '361', 'CDIGO TERCEIRIZADA NO CADASTRADO');
   INCLUI_ERRCNABP ('479', '362', 'NUMERO DO LOTE IGUAL A ZEROS');
   INCLUI_ERRCNABP ('479', '363', 'CONVENIO NO TEM MODALIDADE TERCEIRIZADA');
   INCLUI_ERRCNABP ('479', '364', 'TP.PAGTO INVLIDO P/ TERCEIRIZADA');
   INCLUI_ERRCNABP ('479', '365', 'COD.OCORR.INVAL.P/TERCEIRIZADA');
   INCLUI_ERRCNABP ('479', '371', 'BANCO PARA PAGAMENTO ESTA INATIVO');
   INCLUI_ERRCNABP ('479', '372', 'VALOR TED ABAIXO DO LIMITE');
   INCLUI_ERRCNABP ('479', '373', 'CONTA CORRENTE RESTRITA PARA DEBITO');
   INCLUI_ERRCNABP ('479', '375', 'NUMERO DA AG.DO BCO DESTINO INVLIDA');
   INCLUI_ERRCNABP ('479', '376', 'NUMERO DA C/C DA AG.DO BCO DESTINO INVLIDA');
   INCLUI_ERRCNABP ('479', '511', 'TIPO DE COMPROMISSO SO PARA FOLHA DE PAGAMENTO');
   INCLUI_ERRCNABP ('479', '512', 'TIPO DE PAGAMENTO INVLIDO PARA FOLHA');
   INCLUI_ERRCNABP ('479', '514', 'FORNECEDOR INVLIDO PARA FOLHA DE PAGAMENTO');
   INCLUI_ERRCNABP ('479', '516', 'NOME DO FORNECEDOR NO PREENCHIDO');
   INCLUI_ERRCNABP ('479', '522', 'TIPO DE COMPR.INVAL.P/CONV.C/DEB.EM C.CONTABIL');
   INCLUI_ERRCNABP ('479', '530', 'ALTERAO DE VALOR INVLIDA PARA ESTE CONVENIO');
   INCLUI_ERRCNABP ('479', '535', 'TP PAGTO NO PODE SER CHEQUE P/CONV.DEB.DE CTA CONTABIL');
   INCLUI_ERRCNABP ('479', '810', 'NO EXISTE REGISTRO DE HEADER NO ARQUIVO');
   INCLUI_ERRCNABP ('479', '812', 'VERSAO DO HEADER DO ARQUIVO DIFERENTE DO HEADER NO CONTROLE');
   INCLUI_ERRCNABP ('479', '857', 'OPERAO INVLIDA');
   INCLUI_ERRCNABP ('479', '859', 'COMPROMISSO J AUTORIZADO');
   INCLUI_ERRCNABP ('479', '999', 'COMPROMISSO J LIQUIDADO');
   COMMIT;
END;
/
BEGIN 
   -- BANCO CAIXA ECONMICA FEDERAL 104

   INCLUI_ERRCNABP('104', '00', 'CRDITO OU DBITO EFETIVADO');
   INCLUI_ERRCNABP('104', '00', 'CRDITO OU DBITO EFETIVADO');
   INCLUI_ERRCNABP('104', '01', 'INSUFICINCIA DE FUNDOS - DBITO NO EFETUADO');
   INCLUI_ERRCNABP('104', '02', 'CRDITO OU DBITO CANCELADO PELO PAGADOR/CREDOR');
   INCLUI_ERRCNABP('104', '03', 'DBITO AUTORIZADO PELA AGNCIA - EFETUADO');
   INCLUI_ERRCNABP('104', 'HA', 'LOTE NO ACEITO');
   INCLUI_ERRCNABP('104', 'HB', 'INSCRIO DA EMPRESA INVLIDA PARA O CONTRATO');
   INCLUI_ERRCNABP('104', 'HC', 'CONVNIO COM A EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP('104', 'HD', 'AGNCIA/CONTA CORRENTE DA EMPRESA INEXISTENTE/INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP('104', 'HE', 'TIPO DE SERVIO INVLIDO PARA O CONTRATO');
   INCLUI_ERRCNABP('104', 'HF', 'CONTA CORRENTE DA EMPRESA COM SALDO INSUFICIENTE');
   INCLUI_ERRCNABP('104', 'HG', 'LOTE DE SERVIO FORA DE SEQNCIA');
   INCLUI_ERRCNABP('104', 'HH', 'LOTE DE SERVIO INVLIDO');
   INCLUI_ERRCNABP('104', 'HI', 'NMERO DA REMESSA INVLIDO');
   INCLUI_ERRCNABP('104', 'HJ', 'ARQUIVO SEM HEADER');
   INCLUI_ERRCNABP('104', 'HM', 'VERSO DO ARQUIVO INVLIDO');
   INCLUI_ERRCNABP('104', 'AA', 'CONTROLE INVLIDO');
   INCLUI_ERRCNABP('104', 'AB', 'TIPO DE OPERAO INVLIDO');
   INCLUI_ERRCNABP('104', 'AC', 'TIPO DE SERVIO INVLIDO');
   INCLUI_ERRCNABP('104', 'AD', 'FORMA DE LANAMENTO INVLIDA');
   INCLUI_ERRCNABP('104', 'AE', 'TIPO/NMERO DE INSCRIO INVLIDO');
   INCLUI_ERRCNABP('104', 'AF', 'CDIGO DE CONVNIO INVLIDO');
   INCLUI_ERRCNABP('104', 'AG', 'AGNCIA/CONTA CORRENTE/DV INVLIDO');
   INCLUI_ERRCNABP('104', 'AH', 'NMERO SEQENCIAL DO REGISTRO NO LOTE INVLIDO');
   INCLUI_ERRCNABP('104', 'AI', 'CDIGO DE SEGMENTO DE DETALHE INVLIDO');
   INCLUI_ERRCNABP('104', 'AJ', 'TIPO DE MOVIMENTO INVLIDO');
   INCLUI_ERRCNABP('104', 'AK', 'CDIGO DA CMARA DE COMPENSAO DO BANCO FAVORECIDO/DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP('104', 'AL', 'CDIGO DO BANCO FAVORECIDO OU DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP('104', 'AM', 'AGNCIA MANTENEDORA DA CONTA CORRENTE DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP('104', 'AN', 'CONTA CORRENTE / DV DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP('104', 'AO', 'NOME DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP('104', 'AP', 'DATA DE LANAMENTO INVLIDO');
   INCLUI_ERRCNABP('104', 'AQ', 'TIPO/QUANTIDADE DE MOEDA INVLIDA');
   INCLUI_ERRCNABP('104', 'AR', 'VALOR DO LANAMENTO INVLIDO');
   INCLUI_ERRCNABP('104', 'AS', 'AVISO AO FAVORECIDO - IDENTIFICAO INVLIDA');
   INCLUI_ERRCNABP('104', 'AT', 'TIPO/NMERO DE INSCRIO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP('104', 'AU', 'LOGRADOURO DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP('104', 'AV', 'NMERO DO LOCAL DO FAVORECIDO NO INFORMADO');
   INCLUI_ERRCNABP('104', 'AW', 'CIDADE DO FAVORECIDO NO INFORMADA');
   INCLUI_ERRCNABP('104', 'AX', 'CEP/COMPLEMENTO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP('104', 'AY', 'SIGLA DO ESTADO DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP('104', 'AZ', 'CDIGO/NOME DO BANCO DEPOSITRIO INVLIDO');
   INCLUI_ERRCNABP('104', 'BA', 'CDIGO/NOME DA AGNCIA DEPOSITRIA NO INFORMADO');
   INCLUI_ERRCNABP('104', 'BB', 'SEU NMERO INVLIDO');
   INCLUI_ERRCNABP('104', 'BC', 'NOSSO NMERO INVLIDO');
   INCLUI_ERRCNABP('104', 'BD', 'INCLUSO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP('104', 'BE', 'ALTERAO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP('104', 'BF', 'EXCLUSO EFETUADA COM SUCESSO');
   INCLUI_ERRCNABP('104', 'BG', 'AGNCIA/CONTA IMPEDIDA LEGALMENTE');
   INCLUI_ERRCNABP('104', 'CA', 'CDIGO DE BARRAS - CDIGO DO BANCO INVLIDO');
   INCLUI_ERRCNABP('104', 'CB', 'CDIGO DE BARRAS - CDIGO DA MOEDA INVLIDA');
   INCLUI_ERRCNABP('104', 'CC', 'CDIGO DE BARRAS - DGITO VERIFICADOR GERAL INVLIDO');
   INCLUI_ERRCNABP('104', 'CD', 'CDIGO DE BARRAS - VALOR DO TTULO INVLIDO');
   INCLUI_ERRCNABP('104', 'CE', 'CDIGO DE BARRAS - CAMPO LIVRE INVLIDO');
   INCLUI_ERRCNABP('104', 'CF', 'VALOR DO DOCUMENTO INVLIDO');
   INCLUI_ERRCNABP('104', 'CG', 'VALOR DO ABATIMENTO INVLIDO');
   INCLUI_ERRCNABP('104', 'CH', 'VALOR DO DESCONTO INVLIDO');
   INCLUI_ERRCNABP('104', 'CI', 'VALOR DE MORA INVLIDO');
   INCLUI_ERRCNABP('104', 'CJ', 'VALOR DA MULTA INVLIDO');
   INCLUI_ERRCNABP('104', 'CK', 'VALOR DO IR INVLIDO');
   INCLUI_ERRCNABP('104', 'CL', 'VALOR DO ISS INVLIDO');
   INCLUI_ERRCNABP('104', 'CM', 'VALOR DO IOF INVLIDO');
   INCLUI_ERRCNABP('104', 'CN', 'VALOR DE OUTRAS DEDUES INVLIDO');
   INCLUI_ERRCNABP('104', 'CO', 'VALOR DE OUTROS ACRSCIMOS INVLIDO');
   INCLUI_ERRCNABP('104', 'CP', 'VALOR DO INSS INVLIDO');
   INCLUI_ERRCNABP('104', 'CQ', 'CDIGO DE BARRAS INVLIDO');
   INCLUI_ERRCNABP('104', 'TA', 'LOTE NO ACEITO - TOTAIS DE LOTE COM DIFERENA');
   INCLUI_ERRCNABP('104', 'TB', 'LOTE SEM TRAILLER');
   INCLUI_ERRCNABP('104', 'TC', 'LOTE DE ARQUIVO SEM TRAILLER');
   INCLUI_ERRCNABP('104', 'YA', 'TTULO NO ENCONTRADO');
   INCLUI_ERRCNABP('104', 'YB', 'IDENTIFICADOR REGISTRO OPCIONAL INVLIDO');
   INCLUI_ERRCNABP('104', 'YC', 'CDIGO PADRO INVLIDO');
   INCLUI_ERRCNABP('104', 'YD', 'CDIGO DE OCORRNCIA INVLIDO');
   INCLUI_ERRCNABP('104', 'YE', 'COMPLEMENTO DE OCORRNCIA INVLIDO');
   INCLUI_ERRCNABP('104', 'YF', 'ALEGAO J INFORMADA');
   COMMIT;
END;
/
BEGIN 
   -- BANCO RURAL 453

   INCLUI_ERRCNABP('453', '295', 'Data de vencimeto Cdigo Barras menor que data pagamento');
   INCLUI_ERRCNABP('453', '296', 'Usurio no cadastrado no sistema');
   INCLUI_ERRCNABP('453', '297', 'Cdigo do servio invlido');
   INCLUI_ERRCNABP('453', '298', 'Data de pagamento anterior a data de processamento');
   INCLUI_ERRCNABP('453', '299', 'Espcie de pagamento invlida');
   INCLUI_ERRCNABP('453', '300', 'Tipo de pagamento invlido');
   INCLUI_ERRCNABP('453', '301', 'Dados do favorecido incompletos');
   INCLUI_ERRCNABP('453', '302', 'Nmero do CGC/CPF do favorecido invlido');
   INCLUI_ERRCNABP('453', '303', 'Nmero do CGC/CPF do usuriO invlido');
   INCLUI_ERRCNABP('453', '304', 'Tipo (CGC ou CPF) usurio e/ou favorecido invlido');
   INCLUI_ERRCNABP('453', '305', 'Nmero (CGC ou CPF) usurio e/ou favorecido invlido');
   INCLUI_ERRCNABP('453', '306', 'Finalidade DOC invlida');
   INCLUI_ERRCNABP('453', '307', 'Informar finalidade para o DOC');
   INCLUI_ERRCNABP('453', '308', 'Excluso para registro no cadastrado no Banco');
   INCLUI_ERRCNABP('453', '309', 'Excluso para compromisso com pagamento j efetuado');
   INCLUI_ERRCNABP('453', '310', 'Conta corrente do favorecido invlida');
   INCLUI_ERRCNABP('453', '311', 'Usurio no cadastrado no sistema');
   INCLUI_ERRCNABP('453', '312', 'Falta nome do favorecido');
   INCLUI_ERRCNABP('453', '313', 'Valor invlido / Valor no confere com cdigo de barras');
   INCLUI_ERRCNABP('453', '314', 'Cd. de Barras invlido p/ ttulo compensvel');
   COMMIT;
END;
/
BEGIN 
   -- BANCO MERACANTIL 749

   INCLUI_ERRCNABP('749', '295', 'Data de vencimeto Cdigo Barras menor que data pagamento');
   INCLUI_ERRCNABP('749', '296', 'Usurio no cadastrado no sistema');
   INCLUI_ERRCNABP('749', '297', 'Cdigo do servio invlido');
   INCLUI_ERRCNABP('749', '298', 'Data de pagamento anterior a data de processamento');
   INCLUI_ERRCNABP('749', '299', 'Espcie de pagamento invlida');
   INCLUI_ERRCNABP('749', '300', 'Tipo de pagamento invlido');
   INCLUI_ERRCNABP('749', '301', 'Dados do favorecido incompletos');
   INCLUI_ERRCNABP('749', '302', 'Nmero do CGC/CPF do favorecido invlido');
   INCLUI_ERRCNABP('749', '303', 'Nmero do CGC/CPF do usuriO invlido');
   INCLUI_ERRCNABP('749', '304', 'Tipo (CGC ou CPF) usurio e/ou favorecido invlido');
   INCLUI_ERRCNABP('749', '305', 'Nmero (CGC ou CPF) usurio e/ou favorecido invlido');
   INCLUI_ERRCNABP('749', '306', 'Finalidade DOC invlida');
   INCLUI_ERRCNABP('749', '307', 'Informar finalidade para o DOC');
   INCLUI_ERRCNABP('749', '308', 'Excluso para registro no cadastrado no Banco');
   INCLUI_ERRCNABP('749', '309', 'Excluso para compromisso com pagamento j efetuado');
   INCLUI_ERRCNABP('749', '310', 'Conta corrente do favorecido invlida');
   INCLUI_ERRCNABP('749', '311', 'Usurio no cadastrado no sistema');
   INCLUI_ERRCNABP('749', '312', 'Falta nome do favorecido');
   INCLUI_ERRCNABP('749', '313', 'Valor invlido / Valor no confere com cdigo de barras');
   INCLUI_ERRCNABP('749', '314', 'Cd. de Barras invlido p/ ttulo compensvel');
   COMMIT;
END;
/
BEGIN
   -- BANCO BANRISUL 041
   INCLUI_ERRCNABP('041', 'CC', 'Recusa todo arquivo');
   INCLUI_ERRCNABP('041', '00', 'Crdito efetuado');
   INCLUI_ERRCNABP('041', '01', 'Insuficincia de fundos');
   INCLUI_ERRCNABP('041', '02', 'Crdito cancelado pelo pagador/credor');
   INCLUI_ERRCNABP('041', '03', 'Dbito autorizado pela agncia - efetuado');
   INCLUI_ERRCNABP('041', 'HA', 'Lote no aceito');
   INCLUI_ERRCNABP('041', 'HB', 'Inscrio da empresa invlida para o contrato');
   INCLUI_ERRCNABP('041', 'HC', 'Convnio com a empresa inexistente/invlido para o contrato');
   INCLUI_ERRCNABP('041', 'HD', 'Agncia/conta corrente da empresa inexistente/invlida para o contrato');
   INCLUI_ERRCNABP('041', 'HE', 'Tipo de servio invlido para o contrato');
   INCLUI_ERRCNABP('041', 'HF', 'Conta-Corrente da Empresa com saldo insuficiente');
   INCLUI_ERRCNABP('041', 'AA', 'Controle invlido');
   INCLUI_ERRCNABP('041', 'AB', 'Tipo de operao invlido');
   INCLUI_ERRCNABP('041', 'AC', 'Tipo de servio invlido');
   INCLUI_ERRCNABP('041', 'AD', 'Forma de lanamento invlida');
   INCLUI_ERRCNABP('041', 'AE', 'Tipo/nmero de inscrio invlido');
   INCLUI_ERRCNABP('041', 'AF', 'Cdigo do convnio invlido');
   INCLUI_ERRCNABP('041', 'AG', 'Agncia/conta corrente/Dv invlido');
   INCLUI_ERRCNABP('041', 'AH', 'Nmero seqencial do registro do lote invlido');
   INCLUI_ERRCNABP('041', 'AI', 'Cdigo do Segmento de Detalhe invlido.');
   INCLUI_ERRCNABP('041', 'AJ', 'Tipo de movimento invlido');
   INCLUI_ERRCNABP('041', 'AK', 'Cdigo da cmara de compensao do favorecido invlido');
   INCLUI_ERRCNABP('041', 'AL', 'Banco do favorecido invlido ou Banco no cadastrado na tabela de banos para receber TEDs');
   INCLUI_ERRCNABP('041', 'AM', 'Agncia mantenedora da conta corrente do favorecido invlida.');
   INCLUI_ERRCNABP('041', 'AN', 'Conta corrente/Dv do favorecido invlido');
   INCLUI_ERRCNABP('041', 'AO', 'Nome do favorecido no informado');
   INCLUI_ERRCNABP('041', 'AP', 'Data do lanamento invlida');
   INCLUI_ERRCNABP('041', 'AQ', 'Tipo/quantidade de moeda invlido');
   INCLUI_ERRCNABP('041', 'AR', 'Valor do lanamento invlido');
   INCLUI_ERRCNABP('041', 'AS', 'Aviso ao favorecido - Identificao invlida');
   INCLUI_ERRCNABP('041', 'AT', 'Tipo/nmero de inscrio do favorecido invlido');
   INCLUI_ERRCNABP('041', 'AU', 'Logradouro do favorecido no informado');
   INCLUI_ERRCNABP('041', 'AV', 'Nmero do local do favorecido no informado');
   INCLUI_ERRCNABP('041', 'AW', 'Cidade do favorecido no informado');
   INCLUI_ERRCNABP('041', 'AX', 'Cep/complemento do favorecido invlido');
   INCLUI_ERRCNABP('041', 'AY', 'Sigla do estado do favorecido invlida');
   INCLUI_ERRCNABP('041', 'AZ', 'Cdigo/nome do banco depositrio invlido');
   INCLUI_ERRCNABP('041', 'BA', 'Cdigo/nome da agncia depositria no informado');
   INCLUI_ERRCNABP('041', 'BB', 'Seu nmero invlido');
   INCLUI_ERRCNABP('041', 'BC', 'Nosso nmero invlido');
   INCLUI_ERRCNABP('041', 'BD', 'Confirmao de pagamento agendado');
   INCLUI_ERRCNABP('041', 'BE', 'Cdigo do pagamento invlido');
   INCLUI_ERRCNABP('041', 'BF', 'Perodo de competncia invlido');
   INCLUI_ERRCNABP('041', 'BG', 'Ms de competncia invlido');
   INCLUI_ERRCNABP('041', 'BH', 'Ano de competncia invlido');
   INCLUI_ERRCNABP('041', 'BI', 'Competncia 13 no pode ser antecipada');
   INCLUI_ERRCNABP('041', 'BJ', 'Identificador de pagamento invlido');
   INCLUI_ERRCNABP('041', 'BK', 'Valor da multa invlido');
   INCLUI_ERRCNABP('041', 'BL', 'Valor mnimo de GPS - R$29,00');
   INCLUI_ERRCNABP('041', 'BM', 'Cdigo de Operao para o sistema BLV invlido');
   INCLUI_ERRCNABP('041', 'BN', 'STR006 ou TED fora do horrio');
   INCLUI_ERRCNABP('041', 'BO', 'Pagamento em agncia do mesmo estado do favorecido');
   INCLUI_ERRCNABP('041', 'BP', 'Erro na validao do cdigo de barras de DARF');
   INCLUI_ERRCNABP('041', 'BQ', 'Inconsistncia do cdigo de barras da GPS');
   INCLUI_ERRCNABP('041', 'DD', 'Duplicidade de DOC');
   INCLUI_ERRCNABP('041', 'DT', 'Duplicidade de Ttulo');
   INCLUI_ERRCNABP('041', 'TA', 'Lote no aceito - totais de lote com diferena.');
   INCLUI_ERRCNABP('041', 'XA', 'TED Agendada cancelada pelo Piloto.');
   INCLUI_ERRCNABP('041', 'XC', 'TED cancelada pelo Piloto.');
   INCLUI_ERRCNABP('041', 'XD', 'Devoluo do SPB.');
   INCLUI_ERRCNABP('041', 'XE', 'Devoluo do SPB por erro.');
   INCLUI_ERRCNABP('041', 'XP', 'Devoluo do SPB por situao especial.');
   INCLUI_ERRCNABP('041', 'XR', 'Movimento entre contas invlido');
   INCLUI_ERRCNABP('041', '57', 'Divergncia na indicao da agncia, conta corrente, nome ou CNPJ/CPF do favorecido.');
   INCLUI_ERRCNABP('041', 'ZA', 'Agncia / Conta do Favorecido substitudo.');
   COMMIT;
END;
/
BEGIN
   -- BANCO SICOOB  756
   INCLUI_ERRCNABP ('756', '00', 'Crdito ou Dbito Efetivado');
   INCLUI_ERRCNABP ('756', 'AJ', 'Tipo de Movimento Invlido');
   INCLUI_ERRCNABP ('756', 'BD', 'Incluso Efetuada com Sucesso');
   INCLUI_ERRCNABP ('756', 'PD', 'Transao Pendente de Assinatura');
   INCLUI_ERRCNABP ('756', 'BF', 'Transao Rejeitada');
   COMMIT;
END;
/
BEGIN
   -- BANCO SICOOB  748
   INCLUI_ERRCNABP('748', '00', 'PAGAMENTO EFETUADO');
   INCLUI_ERRCNABP('748', 'AB', 'TIPO DE OPERACAO INVALIDO');
   INCLUI_ERRCNABP('748', 'AC', 'TIPO DE SERVICO INVALIDO');
   INCLUI_ERRCNABP('748', 'AD', 'FORMA NO COMPATVEL');
   INCLUI_ERRCNABP('748', 'AE', 'TIPO/N INSCRICAO INVALIDO');
   INCLUI_ERRCNABP('748', 'AF', 'CODIGO DE CONVENIO INVALIDO');
   INCLUI_ERRCNABP('748', 'AG', 'AGENCIA/CONTA CORRENTE/DV INVLIDO');
   INCLUI_ERRCNABP('748', 'AH', 'NMERO SEQUENCIAL DO REGISTRO NO LOTE INVLIDO');
   INCLUI_ERRCNABP('748', 'AI', 'CODIGO DO SEGMENTO DE DETALHE INVALIDO');
   INCLUI_ERRCNABP('748', 'AJ', 'TIPO DE MOVIMENTO INVALIDO');
   INCLUI_ERRCNABP('748', 'AK', 'CODIGO DA CAMARA DE COMPENSACAO DO BANCO DO FAVORECIDO INVALIDO');
   INCLUI_ERRCNABP('748', 'AL', 'CDIGO DO BANCO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP('748', 'AM', 'AGNCIA DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP('748', 'AN', 'CONTA CORRENTE DO FAVORECIDO INVLIDA');
   INCLUI_ERRCNABP('748', 'AQ', 'TIPO/QUANTIDADE DA MOEDA INVLIDO');
   INCLUI_ERRCNABP('748', 'AO', 'NOME DO FAVORECIDO INVLIDO');
   INCLUI_ERRCNABP('748', 'AP', 'DATA DE LANAMENTO/PAGAMENTO INVLIDA');
   INCLUI_ERRCNABP('748', 'BC', 'NOSSO NMERO INVLIDO');
   INCLUI_ERRCNABP('748', 'BD', 'CONFIRMAO DE PAGAMENTO AGENDADO');
   INCLUI_ERRCNABP('748', 'BE', 'PAGAMENTO AGENDADO COM FORMA ALTERADA PARA OP');
   INCLUI_ERRCNABP('748', 'CE', 'CODIGO DE BARRAS CAMPO LIVRE INVALIDO');
   INCLUI_ERRCNABP('748', 'CF', 'VALOR DO TTULO INVLIDO');
   INCLUI_ERRCNABP('748', 'CG', 'VALOR DO ABATIMENTO INVLIDO');
   INCLUI_ERRCNABP('748', 'CH', 'VALOR DO DESCONTO INVLIDO');
   INCLUI_ERRCNABP('748', 'CI', 'VALOR DA MORA INVLIDO');
   INCLUI_ERRCNABP('748', 'CJ', 'VALOR DA MULTA INVLIDO');
   INCLUI_ERRCNABP('748', 'CN', 'VALOR DA DEDUO INVLIDO');
   INCLUI_ERRCNABP('748', 'CO', 'VALOR DO ACRSCIMO INVLIDO');
   INCLUI_ERRCNABP('748', 'CC', 'DV DO CDIGO DE BARRAS INVLIDO');
   INCLUI_ERRCNABP('748', 'CD', 'VALOR DO TITULO INVALIDO CODIGO DE BARRAS');
   INCLUI_ERRCNABP('748', 'HJ', 'REGISTRO REJEITADO');
   INCLUI_ERRCNABP('748', 'HF', 'SALDO INSUFICIENTE');
   INCLUI_ERRCNABP('748', 'TA', 'LOTE NO ACEITO - TOTAIS DO LOTE COM DIFERENA');

   COMMIT;
END;
/
-- VERSAO --
BEGIN ATUVEROBJ('INCLUI_ERRCNABP','0.00.000'); END;
/
