/* Descrio: A trigger insere registros na tabela LOGOPERA a partir de alteraes nas colunas: SGUNIDADE,
            VRPESOUNID, CDPRODESTO, VRFATOCONV, VRARREDCMP, CDTPCTPAGAR, CDPRODORIG, CDTPINDICE, IDPERVALOR,
            CDINDICE, IDPRODATIVPR, NMFANTPROD e IDTEOROBRIG da tabela PRODUTO */
/* Objetivo: Gerar um log que vai registrar na tabela Geral de Logs de Operaes as alteraes nos campos da tabela Produto listados  seguir:
            SGUNIDADE-Sigla da unidade' de medida,
            VRPESOUNID-Peso (em kg) da unidade do produto,
            CDPRODESTO-Cdigo do produto de estoque,
            VRFATOCONV-Fator de converso do produto na unidade do produto de estoque,
            VRARREDCMP-Valor de arredondamento para compras do produto,
            CDTPCTPAGAR-Cdigo do Tipo de Conta a Pagar,
            CDPRODORIG-Cdigo do produto de origem,
            CDTPINDICE-Cdigo do tipo de ndice financeiro (dirio ou mensal),
            IDPERVALOR-Indicador de percentual ou valor,
            CDINDICE-Cdigo do ndice financeiro,
            IDPRODATIVPR-Identificador de produto ativo,
            NMFANTPROD-Nome Codificado do produto. */



IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LOG_SUP_PRODUTO' AND
                 TYPE   = 'TR' 		        AND
	              U.UID  = O.UID             AND
	              U.NAME = USER)
DROP TRIGGER LOG_SUP_PRODUTO
GO

CREATE TRIGGER LOG_SUP_PRODUTO
ON PRODUTO
FOR INSERT, UPDATE, DELETE
AS
   DECLARE  @V_DSREMOTEADDR     VARCHAR(15);
   DECLARE  @V_DSREMOTEHOST     VARCHAR(15);
   DECLARE  @V_DSSERVERRDM      VARCHAR(20);
   DECLARE  @V_DSSERVMETHOD     VARCHAR(30);
   DECLARE  @V_DSREMOTEOPER     VARCHAR(12);
   DECLARE  @V_DESC             VARCHAR(500);
   DECLARE  @V_ITPESQ           VARCHAR(40);
   DECLARE  @V_NMOPERADOR       VARCHAR(40);
   DECLARE  @V_IDTIPOOPER       VARCHAR(1);
   DECLARE  @V_DTOPER           DATETIME;
/*VARIVEIS DO CURSOR C_CURSOR*/

   DECLARE  @V_ID_COMANDO       VARCHAR(1);

   DECLARE  @V_NMPRODUTO_OLD       VARCHAR(50);
   DECLARE  @V_SGUNIDADE_OLD       VARCHAR(10);
   DECLARE  @V_VRPESOUNID_OLD      DOUBLE PRECISION;
   DECLARE  @V_CDPRODESTO_OLD      VARCHAR(10);
   DECLARE  @V_VRFATOCONV_OLD      DOUBLE PRECISION;
   DECLARE  @V_VRARREDCMP_OLD      DOUBLE PRECISION;
   DECLARE  @V_CDTPCTPAGAR_OLD     VARCHAR(6);
   DECLARE  @V_CDPRODORIG_OLD      VARCHAR(10);
   DECLARE  @V_CDTPINDICE_OLD      VARCHAR(1);
   DECLARE  @V_IDPERVALOR_OLD      VARCHAR(1);
   DECLARE  @V_CDINDICE_OLD        VARCHAR(4);
   DECLARE  @V_IDPRODATIVPR_OLD    VARCHAR(20);
   DECLARE  @V_CDCTBLENTRPR_OLD    VARCHAR(20);
   DECLARE  @V_CDCTBLSAIDPR_OLD    VARCHAR(20);
   DECLARE  @V_CDCTBLPRODPR_OLD    VARCHAR(20);
   DECLARE  @V_CDCTBLCPROPR_OLD    VARCHAR(20);
   DECLARE  @V_CDCTBLPRACPR_OLD    VARCHAR(20);
   DECLARE  @V_CDPRODUTO_OLD       VARCHAR(10);
   DECLARE  @V_CDARVPROD_OLD       VARCHAR(20);
   DECLARE  @V_NMFANTPROD_OLD      VARCHAR(250);
   DECLARE  @V_IDTEOROBRIG_OLD     VARCHAR(1);
   DECLARE  @V_IDVDANALISE_OLD     VARCHAR(1);
   DECLARE  @V_DSFORMULAVDANA_OLD  VARCHAR(200);
   DECLARE  @V_DSFORMULAVDRANA_OLD VARCHAR(200);
   DECLARE  @V_IDPRODPERIG_OLD     VARCHAR(1);
   DECLARE  @V_DSINFADICPROD_OLD   VARCHAR(500);

   DECLARE  @V_NMPRODUTO_NEW    VARCHAR(50);
   DECLARE  @V_SGUNIDADE_NEW    VARCHAR(10);
   DECLARE  @V_VRPESOUNID_NEW   DOUBLE PRECISION;
   DECLARE  @V_CDPRODESTO_NEW   VARCHAR(10);
   DECLARE  @V_VRFATOCONV_NEW   DOUBLE PRECISION;
   DECLARE  @V_VRARREDCMP_NEW   DOUBLE PRECISION;
   DECLARE  @V_CDTPCTPAGAR_NEW  VARCHAR(6);
   DECLARE  @V_CDPRODORIG_NEW   VARCHAR(10);
   DECLARE  @V_CDTPINDICE_NEW   VARCHAR(1);
   DECLARE  @V_IDPERVALOR_NEW   VARCHAR(1);
   DECLARE  @V_CDINDICE_NEW     VARCHAR(4);
   DECLARE  @V_IDPRODATIVPR_NEW VARCHAR(20);
   DECLARE  @V_CDCTBLENTRPR_NEW VARCHAR(20);
   DECLARE  @V_CDCTBLSAIDPR_NEW VARCHAR(20);
   DECLARE  @V_CDCTBLPRODPR_NEW VARCHAR(20);
   DECLARE  @V_CDCTBLCPROPR_NEW VARCHAR(20);
   DECLARE  @V_CDCTBLPRACPR_NEW VARCHAR(20);
   DECLARE  @V_CDPRODUTO_NEW    VARCHAR(10);
   DECLARE  @V_CDARVPROD_NEW    VARCHAR(20);
   DECLARE  @V_NMFANTPROD_NEW   VARCHAR(250);
   DECLARE  @V_IDTEOROBRIG_NEW  VARCHAR(1);
   DECLARE  @V_IDVDANALISE_NEW     VARCHAR(1);
   DECLARE  @V_DSFORMULAVDANA_NEW  VARCHAR(200);
   DECLARE  @V_DSFORMULAVDRANA_NEW VARCHAR(200);
   DECLARE  @V_IDPRODPERIG_NEW     VARCHAR(1);
   DECLARE  @V_DSINFADICPROD_NEW   VARCHAR(500);


BEGIN
/* IDTIPOOPER - '1' - Incluso, '2' - Alterao, '3' - Excluso*/
   SET @V_DESC       = '';
   SET @V_ITPESQ     = '';
   SET @V_NMOPERADOR = '';
   SET @V_IDTIPOOPER = '1';
   EXEC NMUSUARIO @V_NMOPERADOR;
   EXEC WEBTUNNING @V_DSREMOTEADDR,
              @V_DSREMOTEHOST,
              @V_DSSERVERRDM,
              @V_DSSERVMETHOD,
              @V_DSREMOTEOPER;

   DECLARE C_CURSOR CURSOR FOR
   SELECT
      'D' IDCOMANDO,
      NMPRODUTO,
      SGUNIDADE,
      VRPESOUNID,
      CDPRODESTO,
      VRFATOCONV,
      VRARREDCMP,
      CDTPCTPAGAR,
      CDPRODORIG,
      CDTPINDICE,
      IDPERVALOR,
      CDINDICE,
      IDPRODATIVPR,
      CDCTBLENTRPR,
      CDCTBLSAIDPR,
      CDCTBLPRODPR,
      CDCTBLCPROPR,
      CDCTBLPRACPR,
      CDPRODUTO,
      CDARVPROD,
      NMFANTPROD,
      IDTEOROBRIG,
      IDVDANALISE,
      DSFORMULAVDANA,
      DSFORMULAVDRANA,
      IDPRODPERIG,
      DSINFADICPROD,

      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL
   FROM
      DELETED
   WHERE
      CDPRODUTO NOT IN (SELECT CDPRODUTO FROM INSERTED)
   UNION ALL
   SELECT
      'U' IDCOMANDO,
      DELETED.NMPRODUTO,
      DELETED.SGUNIDADE,
      DELETED.VRPESOUNID,
      DELETED.CDPRODESTO,
      DELETED.VRFATOCONV,
      DELETED.VRARREDCMP,
      DELETED.CDTPCTPAGAR,
      DELETED.CDPRODORIG,
      DELETED.CDTPINDICE,
      DELETED.IDPERVALOR,
      DELETED.CDINDICE,
      DELETED.IDPRODATIVPR,
      DELETED.CDCTBLENTRPR,
      DELETED.CDCTBLSAIDPR,
      DELETED.CDCTBLPRODPR,
      DELETED.CDCTBLCPROPR,
      DELETED.CDCTBLPRACPR,
      DELETED.CDPRODUTO,
      DELETED.CDARVPROD,
      DELETED.NMFANTPROD,
      DELETED.IDTEOROBRIG,
      DELETED.IDVDANALISE,
      DELETED.DSFORMULAVDANA,
      DELETED.DSFORMULAVDRANA,
      DELETED.IDPRODPERIG,
      DELETED.DSINFADICPROD,

      INSERTED.NMPRODUTO,
      INSERTED.SGUNIDADE,
      INSERTED.VRPESOUNID,
      INSERTED.CDPRODESTO,
      INSERTED.VRFATOCONV,
      INSERTED.VRARREDCMP,
      INSERTED.CDTPCTPAGAR,
      INSERTED.CDPRODORIG,
      INSERTED.CDTPINDICE,
      INSERTED.IDPERVALOR,
      INSERTED.CDINDICE,
      INSERTED.IDPRODATIVPR,
      INSERTED.CDCTBLENTRPR,
      INSERTED.CDCTBLSAIDPR,
      INSERTED.CDCTBLPRODPR,
      INSERTED.CDCTBLCPROPR,
      INSERTED.CDCTBLPRACPR,
      INSERTED.CDPRODUTO,
      INSERTED.CDARVPROD,
      INSERTED.NMFANTPROD,
      INSERTED.IDTEOROBRIG,
      INSERTED.IDVDANALISE,
      INSERTED.DSFORMULAVDANA,
      INSERTED.DSFORMULAVDRANA,
      INSERTED.IDPRODPERIG,
      INSERTED.DSINFADICPROD
   FROM
      DELETED,
      INSERTED
   WHERE
      INSERTED.CDPRODUTO = DELETED.CDPRODUTO AND
      (ISNULL(DELETED.CDARVPROD   ,0) <> ISNULL(INSERTED.CDARVPROD   ,0)) OR
      (ISNULL(DELETED.CDNVPRODUTO ,0) <> ISNULL(INSERTED.CDNVPRODUTO ,0)) OR
      (ISNULL(DELETED.NMPRODUTO   ,0) <> ISNULL(INSERTED.NMPRODUTO   ,0)) OR
      (ISNULL(DELETED.SGUNIDADE   ,0) <> ISNULL(INSERTED.SGUNIDADE   ,0)) OR
      (ISNULL(DELETED.CDPRODESTO  ,0) <> ISNULL(INSERTED.CDPRODESTO  ,0)) OR
      (ISNULL(DELETED.VRFATOCONV  ,0) <> ISNULL(INSERTED.VRFATOCONV  ,0)) OR
      (ISNULL(DELETED.VRPESOUNID  ,0) <> ISNULL(INSERTED.VRPESOUNID  ,0)) OR
      (ISNULL(DELETED.VRPEFATOCORR,0) <> ISNULL(INSERTED.VRPEFATOCORR,0)) OR
      (ISNULL(DELETED.VRARREDREQ  ,0) <> ISNULL(INSERTED.VRARREDREQ  ,0)) OR
      (ISNULL(DELETED.CDSETOR     ,0) <> ISNULL(INSERTED.CDSETOR     ,0)) OR
      (ISNULL(DELETED.IDPRODATIVPR,0) <> ISNULL(INSERTED.IDPRODATIVPR,0)) OR
      (ISNULL(DELETED.VRARREDCMP  ,0) <> ISNULL(INSERTED.VRARREDCMP  ,0)) OR
      (ISNULL(DELETED.IDINTESAFR  ,0) <> ISNULL(INSERTED.IDINTESAFR  ,0)) OR
      (ISNULL(DELETED.CDBARPRODUTO,0) <> ISNULL(INSERTED.CDBARPRODUTO,0)) OR
      (ISNULL(DELETED.IDPRODCOMISS,0) <> ISNULL(INSERTED.IDPRODCOMISS,0)) OR
      (ISNULL(DELETED.CDCIA       ,0) <> ISNULL(INSERTED.CDCIA       ,0)) OR
      (ISNULL(DELETED.CDCICLO     ,0) <> ISNULL(INSERTED.CDCICLO     ,0)) OR
      (ISNULL(DELETED.CDCLASSE    ,0) <> ISNULL(INSERTED.CDCLASSE    ,0)) OR
      (ISNULL(DELETED.CDPRODINTE  ,0) <> ISNULL(INSERTED.CDPRODINTE  ,0)) OR
      (ISNULL(DELETED.CDPROTECLADO,0) <> ISNULL(INSERTED.CDPROTECLADO,0)) OR
      (ISNULL(DELETED.IDIMPPRODUTO,0) <> ISNULL(INSERTED.IDIMPPRODUTO,0)) OR
      (ISNULL(DELETED.IDPESAPROD  ,0) <> ISNULL(INSERTED.IDPESAPROD  ,0)) OR
      (ISNULL(DELETED.IDCOBTXSERV ,0) <> ISNULL(INSERTED.IDCOBTXSERV ,0)) OR
      (ISNULL(DELETED.IDTIPOPROD  ,0) <> ISNULL(INSERTED.IDTIPOPROD  ,0)) OR
      (ISNULL(DELETED.QTTARAPROD  ,0) <> ISNULL(INSERTED.QTTARAPROD  ,0)) OR
      (ISNULL(DELETED.IDIMPRODUVEZ,0) <> ISNULL(INSERTED.IDIMPRODUVEZ,0)) OR
      (ISNULL(DELETED.NMFANTPROD,0)   <> ISNULL(INSERTED.NMFANTPROD,  0)) OR
      (ISNULL(DELETED.IDTEOROBRIG ,0) <> ISNULL(INSERTED.IDTEOROBRIG ,0)) OR
      (ISNULL(DELETED.IDVDANALISE ,0) <> ISNULL(INSERTED.IDVDANALISE ,0)) OR
      (ISNULL(DELETED.DSFORMULAVDANA ,0) <> ISNULL(INSERTED.DSFORMULAVDANA ,0)) OR
      (ISNULL(DELETED.DSFORMULAVDRANA ,0) <> ISNULL(INSERTED.DSFORMULAVDRANA ,0)) OR
      (ISNULL(DELETED.IDPRODPERIG ,0) <> ISNULL(INSERTED.IDPRODPERIG ,0)) OR
      (ISNULL(DELETED.DSINFADICPROD ,0) <> ISNULL(INSERTED.DSINFADICPROD ,0))
   UNION ALL
   SELECT
      'I' IDCOMANDO,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,
      NULL,

      NMPRODUTO,
      SGUNIDADE,
      VRPESOUNID,
      CDPRODESTO,
      VRFATOCONV,
      VRARREDCMP,
      CDTPCTPAGAR,
      CDPRODORIG,
      CDTPINDICE,
      IDPERVALOR,
      CDINDICE,
      IDPRODATIVPR,
      CDCTBLENTRPR,
      CDCTBLSAIDPR,
      CDCTBLPRODPR,
      CDCTBLCPROPR,
      CDCTBLPRACPR,
      CDPRODUTO,
      CDARVPROD,
      NMFANTPROD,
      IDTEOROBRIG,
      IDVDANALISE,
      DSFORMULAVDANA,
      DSFORMULAVDRANA,
      IDPRODPERIG,
      DSINFADICPROD
   FROM
      INSERTED
   WHERE
      CDPRODUTO NOT IN (SELECT CDPRODUTO FROM DELETED);
   OPEN C_CURSOR;
   FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
                               @V_NMPRODUTO_OLD,
                               @V_SGUNIDADE_OLD,
                               @V_VRPESOUNID_OLD,
                               @V_CDPRODESTO_OLD,
                               @V_VRFATOCONV_OLD,
                               @V_VRARREDCMP_OLD,
                               @V_CDTPCTPAGAR_OLD,
                               @V_CDPRODORIG_OLD,
                               @V_CDTPINDICE_OLD,
                               @V_IDPERVALOR_OLD,
                               @V_CDINDICE_OLD,
                               @V_IDPRODATIVPR_OLD,
                               @V_CDCTBLENTRPR_OLD,
                               @V_CDCTBLSAIDPR_OLD,
                               @V_CDCTBLPRODPR_OLD,
                               @V_CDCTBLCPROPR_OLD,
                               @V_CDCTBLPRACPR_OLD,
                               @V_CDPRODUTO_OLD,
                               @V_CDARVPROD_OLD,
                               @V_NMFANTPROD_OLD,
                               @V_IDTEOROBRIG_OLD,
                               @V_IDVDANALISE_OLD,
                               @V_DSFORMULAVDANA_OLD,
                               @V_DSFORMULAVDRANA_OLD,
                               @V_IDPRODPERIG_OLD,
                               @V_DSINFADICPROD_OLD,

                               @V_NMPRODUTO_NEW,
                               @V_SGUNIDADE_NEW,
                               @V_VRPESOUNID_NEW,
                               @V_CDPRODESTO_NEW,
                               @V_VRFATOCONV_NEW,
                               @V_VRARREDCMP_NEW,
                               @V_CDTPCTPAGAR_NEW,
                               @V_CDPRODORIG_NEW,
                               @V_CDTPINDICE_NEW,
                               @V_IDPERVALOR_NEW,
                               @V_CDINDICE_NEW,
                               @V_IDPRODATIVPR_NEW,
                               @V_CDCTBLENTRPR_NEW,
                               @V_CDCTBLSAIDPR_NEW,
                               @V_CDCTBLPRODPR_NEW,
                               @V_CDCTBLCPROPR_NEW,
                               @V_CDCTBLPRACPR_NEW,
                               @V_CDPRODUTO_NEW,
                               @V_CDARVPROD_NEW,
                               @V_NMFANTPROD_NEW,
                               @V_IDTEOROBRIG_NEW,
                               @V_IDVDANALISE_NEW,
                               @V_DSFORMULAVDANA_NEW,
                               @V_DSFORMULAVDRANA_NEW,
                               @V_IDPRODPERIG_OLD,
                               @V_DSINFADICPROD_OLD;


   WHILE (@@FETCH_STATUS = 0) BEGIN
      IF @V_ID_COMANDO = 'D'/*DELETING*/ BEGIN
         IF NOT (@V_CDARVPROD_OLD IS  NULL) BEGIN
            SET @V_DESC = @V_DESC + 'Produto '      + @V_CDARVPROD_OLD;
         END;
         IF NOT  (@V_CDPRODUTO_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'Cd. Produto ' + @V_CDPRODUTO_OLD;
         END;
         IF NOT   (@V_NMPRODUTO_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'Nome '         + @V_NMPRODUTO_OLD;
         END;
         IF NOT   (@V_SGUNIDADE_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'Unidade '      + @V_SGUNIDADE_OLD;
         END;
         IF NOT   (@V_VRPESOUNID_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'PesoUnid '     + CONVERT(VARCHAR, @V_VRPESOUNID_OLD);
         END;
         IF NOT   (@V_CDPRODESTO_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'ProdEst '      + @V_CDPRODESTO_OLD;
         END;
         IF NOT   (@V_VRFATOCONV_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'FatorConv '   +  CONVERT(VARCHAR, @V_VRFATOCONV_OLD);
         END;
         IF NOT   (@V_VRARREDCMP_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'ArreCmp '     +  CONVERT(VARCHAR, @V_VRARREDCMP_OLD);
         END;
         IF NOT   (@V_CDTPCTPAGAR_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'TpCtbPag '    +  @V_CDTPCTPAGAR_OLD;
         END;
         IF NOT   (@V_CDPRODORIG_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'ProgOrig '    +  @V_CDPRODORIG_OLD;
         END;
         IF NOT   (@V_CDTPINDICE_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'CdTPIndice '  +  @V_CDTPINDICE_OLD;
         END;
         IF NOT   (@V_IDPERVALOR_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'IdIndice '    +  @V_IDPERVALOR_OLD;
         END;
         IF NOT   (@V_IDPERVALOR_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'CdIndice '    +  @V_CDINDICE_OLD;
         END;
         IF NOT   (@V_IDPRODATIVPR_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'ProdAtiv '    +  @V_IDPRODATIVPR_OLD;
         END;
         IF NOT   (@V_CDCTBLENTRPR_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'CtblEntrada='  +  @V_CDCTBLENTRPR_OLD;
         END;
         IF NOT   (@V_CDCTBLSAIDPR_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'CtblSaida='    +   @V_CDCTBLSAIDPR_OLD;
         END;
         IF NOT   (@V_CDCTBLPRODPR_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'CtblCustoProd='+  @V_CDCTBLPRODPR_OLD;
         END;
         IF NOT   (@V_CDCTBLPRODPR_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'CtblContraProva='+  @V_CDCTBLCPROPR_OLD;
         END;
         IF NOT   (@V_CDCTBLPRACPR_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'CtblCMV='     +   @V_CDCTBLPRACPR_OLD;
         END;
         IF NOT   (@V_NMFANTPROD_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'NmCod='     +   @V_NMFANTPROD_OLD;
         END;
         IF NOT   (@V_IDTEOROBRIG_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'IdTeorObrig='     +   @V_IDTEOROBRIG_OLD;
         END;
         IF NOT   (@V_IDVDANALISE_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'IdVdAnalise=' +   @V_IDVDANALISE_OLD;
         END;
         IF NOT   (@V_DSFORMULAVDANA_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'DsFormulaVdAna=' +   @V_DSFORMULAVDANA_OLD;
         END;
         IF NOT   (@V_DSFORMULAVDRANA_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'DsFormulaVdRAna=' +   @V_DSFORMULAVDRANA_OLD;
         END;
         IF NOT   (@V_IDPRODPERIG_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'IdProdPerig=' +   @V_IDPRODPERIG_OLD;
         END;
         IF NOT   (@V_DSINFADICPROD_OLD IS NULL) BEGIN
            SET @V_DESC = @V_DESC + 'DsInfAdicProd=' +   @V_DSINFADICPROD_OLD;
         END;

         SET @V_IDTIPOOPER   = '3';
         SET @V_ITPESQ = @V_CDARVPROD_OLD;

      END
      ELSE  IF @V_ID_COMANDO = 'U'/*UPDATING*/ BEGIN
         IF(@V_NMPRODUTO_OLD    <> @V_NMPRODUTO_NEW)    OR
           (@V_SGUNIDADE_OLD    <> @V_SGUNIDADE_NEW)    OR
           (@V_VRPESOUNID_OLD   <> @V_VRPESOUNID_NEW)   OR
           (@V_CDPRODESTO_OLD   <> @V_CDPRODESTO_NEW)   OR
           (@V_VRFATOCONV_OLD   <> @V_VRFATOCONV_NEW)   OR
           (@V_VRARREDCMP_OLD   <> @V_VRARREDCMP_NEW)   OR
           (@V_CDTPCTPAGAR_OLD  <> @V_CDTPCTPAGAR_NEW)  OR
           (@V_CDPRODORIG_OLD   <> @V_CDPRODORIG_NEW)   OR
           (@V_CDTPINDICE_OLD   <> @V_CDTPINDICE_NEW)   OR
           (@V_IDPERVALOR_OLD   <> @V_IDPERVALOR_NEW)   OR
           (@V_CDINDICE_OLD     <> @V_CDINDICE_NEW )    OR
           (@V_IDPRODATIVPR_OLD <> @V_IDPRODATIVPR_NEW) OR
           (@V_CDCTBLENTRPR_OLD <> @V_CDCTBLENTRPR_NEW) OR
           (@V_CDCTBLSAIDPR_OLD <> @V_CDCTBLSAIDPR_NEW) OR
           (@V_CDCTBLPRODPR_OLD <> @V_CDCTBLPRODPR_NEW) OR
           (@V_CDCTBLCPROPR_OLD <> @V_CDCTBLCPROPR_NEW) OR
           (@V_CDCTBLPRACPR_OLD <> @V_CDCTBLPRACPR_NEW) OR
           (@V_CDPRODUTO_OLD    <> @V_CDPRODUTO_NEW)    OR
           (@V_CDARVPROD_OLD    <> @V_CDARVPROD_NEW)    OR
           (@V_NMFANTPROD_OLD   <> @V_NMFANTPROD_NEW)   OR
           (@V_IDTEOROBRIG_OLD  <> @V_IDTEOROBRIG_NEW)  OR
           (@V_IDPRODPERIG_OLD  <> @V_IDPRODPERIG_NEW)  OR
           (@V_DSINFADICPROD_OLD <> @V_DSINFADICPROD_NEW) BEGIN

            SET @V_IDTIPOOPER = '2';
            SET @V_ITPESQ = @V_CDPRODUTO_NEW;
            IF ISNULL(@V_CDARVPROD_OLD, '') <> ISNULL(@V_CDARVPROD_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'Produto '      + '' + @V_CDARVPROD_NEW;
      	   END;
            IF ISNULL(@V_CDPRODUTO_OLD, '') <> ISNULL(@V_CDPRODUTO_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'Cd. Produto ' + '' + @V_CDPRODUTO_NEW;
            END;
            IF ISNULL(@V_NMPRODUTO_OLD, '') <> ISNULL(@V_NMPRODUTO_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'Nome '        + '' + @V_NMPRODUTO_NEW;
            END;
            IF ISNULL(@V_SGUNIDADE_OLD, '') <> ISNULL(@V_SGUNIDADE_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'Unidade '      + '' + @V_SGUNIDADE_NEW;
            END;
            IF ISNULL(@V_VRPESOUNID_OLD,  0) <> ISNULL(@V_VRPESOUNID_NEW,0) BEGIN
               SET @V_DESC = @V_DESC + 'PesoUnid '     + '' + CONVERT(VARCHAR, @V_VRPESOUNID_NEW);
            END;
            IF ISNULL(@V_CDPRODESTO_OLD, '') <> ISNULL(@V_CDPRODESTO_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'ProdEst '     + '' + @V_CDPRODESTO_NEW;
            END;
            IF ISNULL(@V_VRFATOCONV_OLD, 0) <> ISNULL(@V_VRFATOCONV_NEW, 0) BEGIN
               SET @V_DESC = @V_DESC + 'FatorConv '   + '' + CONVERT(VARCHAR, @V_VRFATOCONV_NEW);
            END;
            IF ISNULL(@V_VRARREDCMP_OLD, 0) <> ISNULL(@V_VRARREDCMP_NEW, 0) BEGIN
               SET @V_DESC = @V_DESC + 'ArreCmp '     + '' + CONVERT(VARCHAR, @V_VRARREDCMP_NEW);
            END;
            IF ISNULL(@V_CDTPCTPAGAR_OLD, '') <> ISNULL(@V_CDTPCTPAGAR_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'TpCtbPag '    + '' + @V_CDTPCTPAGAR_NEW;
            END;
            IF ISNULL(@V_CDPRODORIG_OLD, '') <> ISNULL(@V_CDPRODORIG_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'ProgOrig '    + '' + @V_CDPRODORIG_NEW;
            END;
            IF ISNULL(@V_CDTPINDICE_OLD, '') <> ISNULL(@V_CDTPINDICE_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'CdTPIndice '  + '' + @V_CDTPINDICE_NEW;
            END;
            IF ISNULL(@V_IDPERVALOR_OLD, '') <> ISNULL(@V_IDPERVALOR_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'IdIndice '    + '' + @V_IDPERVALOR_NEW;
            END;
            IF ISNULL(@V_CDINDICE_OLD, '') <> ISNULL(@V_CDINDICE_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'CdIndice '    + '' + @V_CDINDICE_NEW;
            END;
            IF ISNULL(@V_IDPRODATIVPR_OLD, '') <> ISNULL(@V_IDPRODATIVPR_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'ProdAtiv '    + '' + @V_IDPRODATIVPR_NEW;
            END;
            IF ISNULL(@V_CDCTBLENTRPR_OLD, '') <> ISNULL(@V_CDCTBLENTRPR_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'CtblEntrada='      + @V_CDCTBLENTRPR_NEW;
            END;
            IF ISNULL(@V_CDCTBLSAIDPR_OLD, '') <> ISNULL(@V_CDCTBLSAIDPR_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'CtblSaida='        + @V_CDCTBLSAIDPR_NEW;
            END;
            IF ISNULL(@V_CDCTBLPRODPR_OLD, '') <> ISNULL(@V_CDCTBLPRODPR_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'CtblCustoProd='    + @V_CDCTBLPRODPR_NEW;
            END;
            IF ISNULL(@V_CDCTBLPRODPR_OLD, '') <> ISNULL(@V_CDCTBLPRODPR_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'CtblContraProva='  + @V_CDCTBLCPROPR_NEW;
            END;
            IF ISNULL(@V_CDCTBLPRACPR_OLD, '') <> ISNULL(@V_CDCTBLPRACPR_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'CtblCMV='          + @V_CDCTBLPRACPR_NEW;
            END;
            IF ISNULL(@V_NMFANTPROD_OLD, '') <> ISNULL(@V_NMFANTPROD_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'NmCod='          + @V_NMFANTPROD_NEW;
            END;
            IF ISNULL(@V_IDTEOROBRIG_OLD, '') <> ISNULL(@V_IDTEOROBRIG_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'IdTeorObrig='          + @V_IDTEOROBRIG_NEW;
            END;
            IF ISNULL(@V_IDVDANALISE_OLD, '') <> ISNULL(@V_IDVDANALISE_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'IdVdAnalise=' + @V_IDVDANALISE_NEW;
            END;
            IF ISNULL(@V_DSFORMULAVDANA_OLD, '') <> ISNULL(@V_DSFORMULAVDANA_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'DsFormulaVdAna=' + @V_DSFORMULAVDANA_NEW;
            END;
            IF ISNULL(@V_DSFORMULAVDRANA_OLD, '') <> ISNULL(@V_DSFORMULAVDRANA_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'DsFormulaVdRAna=' + @V_DSFORMULAVDRANA_NEW;
            END;
            IF ISNULL(@V_IDPRODPERIG_OLD, '') <> ISNULL(@V_IDPRODPERIG_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'IdProdPerig=' + @V_IDPRODPERIG_NEW;
            END;
            IF ISNULL(@V_DSINFADICPROD_OLD, '') <> ISNULL(@V_DSINFADICPROD_NEW, '') BEGIN
               SET @V_DESC = @V_DESC + 'DsInfAdicProd=' + @V_DSINFADICPROD_NEW;
            END;
         END;
      END
      ELSE BEGIN
         SET @V_IDTIPOOPER = '1';
         SET @V_ITPESQ     =  @V_CDARVPROD_NEW;

         SET @V_DESC = @V_DESC + 'Produto '      + '' + @V_CDARVPROD_NEW;
         SET @V_DESC = @V_DESC + 'Cd. Produto ' + '' + @V_CDPRODUTO_NEW;
         SET @V_DESC = @V_DESC + 'NmCod ' + '' + @V_NMFANTPROD_NEW;
      END;
      IF (@V_IDTIPOOPER <> '0')  BEGIN
          EXEC NMUSUARIO @V_NMOPERADOR;
         IF NOT @V_DESC IS NULL BEGIN
            IF NOT @V_NMOPERADOR IS NULL BEGIN
               EXEC NMUSUARIO @V_NMOPERADOR;
               SET  @V_DTOPER = GETDATE();
               SET  @V_DESC = SUBSTRING(@V_DESC, 1, 300);
               INSERT INTO LOGOPERA
                        (NMTABELA , DTOPERACAO, NMRESPOPER, IDTIPOOPER, DSOPERACAO, CDPESQITEM,
                         DSRDMUSUOPER, DSENDUSUOPER, DSNMUSUOPER, DSMETUSUOPER, CDORESPOPER)
               VALUES
                        ('PRODUTO',      GETDATE(),       ISNULL(@V_NMOPERADOR,''), @V_IDTIPOOPER,   @V_DESC, @V_ITPESQ,
                         @V_DSSERVERRDM, @V_DSREMOTEADDR, @V_DSREMOTEHOST,          @V_DSSERVMETHOD, @V_DSREMOTEOPER);
            END;
         END;
      END;
      FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
                                    @V_NMPRODUTO_OLD,
                                    @V_SGUNIDADE_OLD,
                                    @V_VRPESOUNID_OLD,
                                    @V_CDPRODESTO_OLD,
                                    @V_VRFATOCONV_OLD,
                                    @V_VRARREDCMP_OLD,
                                    @V_CDTPCTPAGAR_OLD,
                                    @V_CDPRODORIG_OLD,
                                    @V_CDTPINDICE_OLD,
                                    @V_IDPERVALOR_OLD,
                                    @V_CDINDICE_OLD,
                                    @V_IDPRODATIVPR_OLD,
                                    @V_CDCTBLENTRPR_OLD,
                                    @V_CDCTBLSAIDPR_OLD,
                                    @V_CDCTBLPRODPR_OLD,
                                    @V_CDCTBLCPROPR_OLD,
                                    @V_CDCTBLPRACPR_OLD,
                                    @V_CDARVPROD_OLD,
                                    @V_CDPRODUTO_OLD,
                                    @V_NMFANTPROD_OLD,
                                    @V_IDTEOROBRIG_OLD,
                                    @V_IDVDANALISE_OLD,
                                    @V_DSFORMULAVDANA_OLD,
                                    @V_DSFORMULAVDRANA_OLD,
                                    @V_IDPRODPERIG_OLD,
                                    @V_DSINFADICPROD_OLD,

                                    @V_NMPRODUTO_NEW,
                                    @V_SGUNIDADE_NEW,
                                    @V_VRPESOUNID_NEW,
                                    @V_CDPRODESTO_NEW,
                                    @V_VRFATOCONV_NEW,
                                    @V_VRARREDCMP_NEW,
                                    @V_CDTPCTPAGAR_NEW,
                                    @V_CDPRODORIG_NEW,
                                    @V_CDTPINDICE_NEW,
                                    @V_IDPERVALOR_NEW,
                                    @V_CDINDICE_NEW,
                                    @V_IDPRODATIVPR_NEW,
                                    @V_CDCTBLENTRPR_NEW,
                                    @V_CDCTBLSAIDPR_NEW,
                                    @V_CDCTBLPRODPR_NEW,
                                    @V_CDCTBLCPROPR_NEW,
                                    @V_CDCTBLPRACPR_NEW,
                                    @V_CDARVPROD_NEW,
                                    @V_CDPRODUTO_NEW,
                                    @V_NMFANTPROD_NEW,
                                    @V_IDTEOROBRIG_NEW,
                                    @V_IDVDANALISE_NEW,
                                    @V_DSFORMULAVDANA_NEW,
                                    @V_DSFORMULAVDRANA_NEW,
                                    @V_IDPRODPERIG_OLD,
                                    @V_DSINFADICPROD_OLD;
   END;
   CLOSE      C_CURSOR;
   DEALLOCATE C_CURSOR;
END;
 GO

 -- VERSAO --
 EXEC ATUVEROBJ 'LOG_SUP_PRODUTO','6.10.xxx';
 GO

